@@ -23,12 +23,14 @@
 #include "gnutls_int.h"
 #include "errors.h"
 #ifdef STDC_HEADERS
-# include <stdarg.h>
+#include <stdarg.h>
 #endif
 #include "str.h"
 
-#define ERROR_ENTRY(desc, name) \
-	{ desc, #name, name}
+#define ERROR_ENTRY(desc, name)   \
+	{                         \
+		desc, #name, name \
+	}
 
 struct gnutls_error_entry {
 	const char *desc;
@@ -54,26 +56,26 @@ static const gnutls_error_entry error_entries[] = {
 
 	ERROR_ENTRY(N_("An algorithm that is not enabled was negotiated."),
 		    GNUTLS_E_UNWANTED_ALGORITHM),
-	ERROR_ENTRY(N_
-		    ("A packet with illegal or unsupported version was received."),
-		    GNUTLS_E_UNSUPPORTED_VERSION_PACKET),
-	ERROR_ENTRY(N_
-		    ("The Diffie-Hellman prime sent by the server is not acceptable (not long enough)."),
-		    GNUTLS_E_DH_PRIME_UNACCEPTABLE),
+	ERROR_ENTRY(
+		N_("A packet with illegal or unsupported version was received."),
+		GNUTLS_E_UNSUPPORTED_VERSION_PACKET),
+	ERROR_ENTRY(
+		N_("The Diffie-Hellman prime sent by the server is not acceptable (not long enough)."),
+		GNUTLS_E_DH_PRIME_UNACCEPTABLE),
 	ERROR_ENTRY(N_("Error decoding the received TLS packet."),
 		    GNUTLS_E_UNEXPECTED_PACKET_LENGTH),
 	ERROR_ENTRY(N_("A TLS record packet with invalid length was received."),
 		    GNUTLS_E_RECORD_OVERFLOW),
 	ERROR_ENTRY(N_("The TLS connection was non-properly terminated."),
 		    GNUTLS_E_PREMATURE_TERMINATION),
-	ERROR_ENTRY(N_
-		    ("The specified session has been invalidated for some reason."),
-		    GNUTLS_E_INVALID_SESSION),
+	ERROR_ENTRY(
+		N_("The specified session has been invalidated for some reason."),
+		GNUTLS_E_INVALID_SESSION),
 
 	ERROR_ENTRY(N_("GnuTLS internal error."), GNUTLS_E_INTERNAL_ERROR),
-	ERROR_ENTRY(N_
-		    ("A connection with inappropriate fallback was attempted."),
-		    GNUTLS_E_INAPPROPRIATE_FALLBACK),
+	ERROR_ENTRY(
+		N_("A connection with inappropriate fallback was attempted."),
+		GNUTLS_E_INAPPROPRIATE_FALLBACK),
 	ERROR_ENTRY(N_("An illegal TLS extension was received."),
 		    GNUTLS_E_RECEIVED_ILLEGAL_EXTENSION),
 	ERROR_ENTRY(N_("An required TLS extension was received."),
@@ -84,19 +86,19 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_UNEXPECTED_PACKET),
 	ERROR_ENTRY(N_("Failed to import the key into store."),
 		    GNUTLS_E_KEY_IMPORT_FAILED),
-	ERROR_ENTRY(N_
-		    ("An error was encountered at the TLS Finished packet calculation."),
-		    GNUTLS_E_ERROR_IN_FINISHED_PACKET),
+	ERROR_ENTRY(
+		N_("An error was encountered at the TLS Finished packet calculation."),
+		GNUTLS_E_ERROR_IN_FINISHED_PACKET),
 	ERROR_ENTRY(N_("No certificate was found."),
 		    GNUTLS_E_NO_CERTIFICATE_FOUND),
 	ERROR_ENTRY(N_("Certificate is required."),
 		    GNUTLS_E_CERTIFICATE_REQUIRED),
-	ERROR_ENTRY(N_
-		    ("The given DSA key is incompatible with the selected TLS protocol."),
-		    GNUTLS_E_INCOMPAT_DSA_KEY_WITH_TLS_PROTOCOL),
-	ERROR_ENTRY(N_
-		    ("There is already a crypto algorithm with lower priority."),
-		    GNUTLS_E_CRYPTO_ALREADY_REGISTERED),
+	ERROR_ENTRY(
+		N_("The given DSA key is incompatible with the selected TLS protocol."),
+		GNUTLS_E_INCOMPAT_DSA_KEY_WITH_TLS_PROTOCOL),
+	ERROR_ENTRY(
+		N_("There is already a crypto algorithm with lower priority."),
+		GNUTLS_E_CRYPTO_ALREADY_REGISTERED),
 
 	ERROR_ENTRY(N_("No temporary RSA parameters were found."),
 		    GNUTLS_E_NO_TEMPORARY_RSA_PARAMS),
@@ -108,10 +110,8 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_MPI_SCAN_FAILED),
 	ERROR_ENTRY(N_("Could not export a large integer."),
 		    GNUTLS_E_MPI_PRINT_FAILED),
-	ERROR_ENTRY(N_("Decryption has failed."),
-		    GNUTLS_E_DECRYPTION_FAILED),
-	ERROR_ENTRY(N_("Encryption has failed."),
-		    GNUTLS_E_ENCRYPTION_FAILED),
+	ERROR_ENTRY(N_("Decryption has failed."), GNUTLS_E_DECRYPTION_FAILED),
+	ERROR_ENTRY(N_("Encryption has failed."), GNUTLS_E_ENCRYPTION_FAILED),
 	ERROR_ENTRY(N_("Public key decryption has failed."),
 		    GNUTLS_E_PK_DECRYPTION_FAILED),
 	ERROR_ENTRY(N_("Public key encryption has failed."),
@@ -127,9 +127,9 @@ static const gnutls_error_entry error_entries[] = {
 
 	ERROR_ENTRY(N_("Internal error in memory allocation."),
 		    GNUTLS_E_MEMORY_ERROR),
-	ERROR_ENTRY(N_
-		    ("An unimplemented or disabled feature has been requested."),
-		    GNUTLS_E_UNIMPLEMENTED_FEATURE),
+	ERROR_ENTRY(
+		N_("An unimplemented or disabled feature has been requested."),
+		GNUTLS_E_UNIMPLEMENTED_FEATURE),
 	ERROR_ENTRY(N_("Insufficient credentials for that request."),
 		    GNUTLS_E_INSUFFICIENT_CREDENTIALS),
 	ERROR_ENTRY(N_("Error in password/key file."), GNUTLS_E_SRP_PWD_ERROR),
@@ -154,9 +154,9 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_NO_EMBEDDED_DATA),
 	ERROR_ENTRY(N_("Error in the pull function."), GNUTLS_E_PULL_ERROR),
 	ERROR_ENTRY(N_("Error in the push function."), GNUTLS_E_PUSH_ERROR),
-	ERROR_ENTRY(N_
-		    ("The upper limit of record packet sequence numbers has been reached. Wow!"),
-		    GNUTLS_E_RECORD_LIMIT_REACHED),
+	ERROR_ENTRY(
+		N_("The upper limit of record packet sequence numbers has been reached. Wow!"),
+		GNUTLS_E_RECORD_LIMIT_REACHED),
 	ERROR_ENTRY(N_("Error in the certificate."),
 		    GNUTLS_E_CERTIFICATE_ERROR),
 	ERROR_ENTRY(N_("Error in the time fields of certificate."),
@@ -165,17 +165,15 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_CERTIFICATE_VERIFICATION_ERROR),
 	ERROR_ENTRY(N_("Error in the CRL verification."),
 		    GNUTLS_E_CRL_VERIFICATION_ERROR),
-	ERROR_ENTRY(N_
-		    ("Error in the private key verification; seed doesn't match."),
-		    GNUTLS_E_PRIVKEY_VERIFICATION_ERROR),
-	ERROR_ENTRY(N_("Could not authenticate peer."),
-		    GNUTLS_E_AUTH_ERROR),
-	ERROR_ENTRY(N_
-		    ("Unknown Subject Alternative name in X.509 certificate."),
+	ERROR_ENTRY(
+		N_("Error in the private key verification; seed doesn't match."),
+		GNUTLS_E_PRIVKEY_VERIFICATION_ERROR),
+	ERROR_ENTRY(N_("Could not authenticate peer."), GNUTLS_E_AUTH_ERROR),
+	ERROR_ENTRY(N_("Unknown Subject Alternative name in X.509 certificate."),
 		    GNUTLS_E_X509_UNKNOWN_SAN),
-	ERROR_ENTRY(N_
-		    ("CIDR name constraint is malformed in size or structure."),
-		    GNUTLS_E_MALFORMED_CIDR),
+	ERROR_ENTRY(
+		N_("CIDR name constraint is malformed in size or structure."),
+		GNUTLS_E_MALFORMED_CIDR),
 
 	ERROR_ENTRY(N_("Unsupported critical extension in X.509 certificate."),
 		    GNUTLS_E_X509_UNSUPPORTED_CRITICAL_EXTENSION),
@@ -186,19 +184,18 @@ static const gnutls_error_entry error_entries[] = {
 	ERROR_ENTRY(N_("Key usage violation in certificate has been detected."),
 		    GNUTLS_E_KEY_USAGE_VIOLATION),
 	ERROR_ENTRY(N_("Function was interrupted."), GNUTLS_E_INTERRUPTED),
-	ERROR_ENTRY(N_
-		    ("TLS Application data were received, while expecting handshake data."),
-		    GNUTLS_E_GOT_APPLICATION_DATA),
+	ERROR_ENTRY(
+		N_("TLS Application data were received, while expecting handshake data."),
+		GNUTLS_E_GOT_APPLICATION_DATA),
 	ERROR_ENTRY(N_("Error in Database backend."), GNUTLS_E_DB_ERROR),
 	ERROR_ENTRY(N_("The Database entry already exists."),
 		    GNUTLS_E_DB_ENTRY_EXISTS),
 	ERROR_ENTRY(N_("The certificate type is not supported."),
 		    GNUTLS_E_UNSUPPORTED_CERTIFICATE_TYPE),
-	ERROR_ENTRY(N_
-		    ("The given memory buffer is too short to hold parameters."),
-		    GNUTLS_E_SHORT_MEMORY_BUFFER),
-	ERROR_ENTRY(N_("The request is invalid."),
-		    GNUTLS_E_INVALID_REQUEST),
+	ERROR_ENTRY(
+		N_("The given memory buffer is too short to hold parameters."),
+		GNUTLS_E_SHORT_MEMORY_BUFFER),
+	ERROR_ENTRY(N_("The request is invalid."), GNUTLS_E_INVALID_REQUEST),
 	ERROR_ENTRY(N_("The cookie was bad."), GNUTLS_E_BAD_COOKIE),
 	ERROR_ENTRY(N_("An illegal parameter has been received."),
 		    GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER),
@@ -220,8 +217,7 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_ASN1_GENERIC_ERROR),
 	ERROR_ENTRY(N_("ASN1 parser: Value is not valid."),
 		    GNUTLS_E_ASN1_VALUE_NOT_VALID),
-	ERROR_ENTRY(N_("ASN1 parser: Error in TAG."),
-		    GNUTLS_E_ASN1_TAG_ERROR),
+	ERROR_ENTRY(N_("ASN1 parser: Error in TAG."), GNUTLS_E_ASN1_TAG_ERROR),
 	ERROR_ENTRY(N_("ASN1 parser: error in implicit tag"),
 		    GNUTLS_E_ASN1_TAG_IMPLICIT),
 	ERROR_ENTRY(N_("ASN1 parser: Error in type 'ANY'."),
@@ -286,9 +282,9 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_INVALID_PASSWORD),
 	ERROR_ENTRY(N_("The given string contains invalid UTF-8 characters."),
 		    GNUTLS_E_INVALID_UTF8_STRING),
-	ERROR_ENTRY(N_
-		    ("The given email string contains non-ASCII characters before '@'."),
-		    GNUTLS_E_INVALID_UTF8_EMAIL),
+	ERROR_ENTRY(
+		N_("The given email string contains non-ASCII characters before '@'."),
+		GNUTLS_E_INVALID_UTF8_EMAIL),
 	ERROR_ENTRY(N_("The given password contains invalid characters."),
 		    GNUTLS_E_INVALID_PASSWORD_STRING),
 	ERROR_ENTRY(N_("The Message Authentication Code verification failed."),
@@ -316,57 +312,43 @@ static const gnutls_error_entry error_entries[] = {
 	ERROR_ENTRY(N_("Channel binding data not available"),
 		    GNUTLS_E_CHANNEL_BINDING_NOT_AVAILABLE),
 
-	ERROR_ENTRY(N_("TPM error."),
-		    GNUTLS_E_TPM_ERROR),
+	ERROR_ENTRY(N_("TPM error."), GNUTLS_E_TPM_ERROR),
 	ERROR_ENTRY(N_("The TPM library (trousers) cannot be found."),
 		    GNUTLS_E_TPM_NO_LIB),
-	ERROR_ENTRY(N_("TPM is not initialized."),
-		    GNUTLS_E_TPM_UNINITIALIZED),
+	ERROR_ENTRY(N_("TPM is not initialized."), GNUTLS_E_TPM_UNINITIALIZED),
 	ERROR_ENTRY(N_("TPM key was not found in persistent storage."),
 		    GNUTLS_E_TPM_KEY_NOT_FOUND),
 	ERROR_ENTRY(N_("Cannot initialize a session with the TPM."),
 		    GNUTLS_E_TPM_SESSION_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 error."),
-		    GNUTLS_E_PKCS11_ERROR),
+	ERROR_ENTRY(N_("PKCS #11 error."), GNUTLS_E_PKCS11_ERROR),
 	ERROR_ENTRY(N_("PKCS #11 initialization error."),
 		    GNUTLS_E_PKCS11_LOAD_ERROR),
-	ERROR_ENTRY(N_("Error in parsing."),
-		    GNUTLS_E_PARSING_ERROR),
-	ERROR_ENTRY(N_("Error in provided PIN."),
-		    GNUTLS_E_PKCS11_PIN_ERROR),
+	ERROR_ENTRY(N_("Error in parsing."), GNUTLS_E_PARSING_ERROR),
+	ERROR_ENTRY(N_("Error in provided PIN."), GNUTLS_E_PKCS11_PIN_ERROR),
 	ERROR_ENTRY(N_("Error in provided SRK password for TPM."),
 		    GNUTLS_E_TPM_SRK_PASSWORD_ERROR),
-	ERROR_ENTRY(N_
-		    ("Error in provided password for key to be loaded in TPM."),
-		    GNUTLS_E_TPM_KEY_PASSWORD_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 error in slot"),
-		    GNUTLS_E_PKCS11_SLOT_ERROR),
-	ERROR_ENTRY(N_("Thread locking error"),
-		    GNUTLS_E_LOCKING_ERROR),
+	ERROR_ENTRY(
+		N_("Error in provided password for key to be loaded in TPM."),
+		GNUTLS_E_TPM_KEY_PASSWORD_ERROR),
+	ERROR_ENTRY(N_("PKCS #11 error in slot"), GNUTLS_E_PKCS11_SLOT_ERROR),
+	ERROR_ENTRY(N_("Thread locking error"), GNUTLS_E_LOCKING_ERROR),
 	ERROR_ENTRY(N_("PKCS #11 error in attribute"),
 		    GNUTLS_E_PKCS11_ATTRIBUTE_ERROR),
 	ERROR_ENTRY(N_("PKCS #11 error in device"),
 		    GNUTLS_E_PKCS11_DEVICE_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 error in data"),
-		    GNUTLS_E_PKCS11_DATA_ERROR),
+	ERROR_ENTRY(N_("PKCS #11 error in data"), GNUTLS_E_PKCS11_DATA_ERROR),
 	ERROR_ENTRY(N_("PKCS #11 unsupported feature"),
 		    GNUTLS_E_PKCS11_UNSUPPORTED_FEATURE_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 error in key"),
-		    GNUTLS_E_PKCS11_KEY_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 PIN expired"),
-		    GNUTLS_E_PKCS11_PIN_EXPIRED),
-	ERROR_ENTRY(N_("PKCS #11 PIN locked"),
-		    GNUTLS_E_PKCS11_PIN_LOCKED),
+	ERROR_ENTRY(N_("PKCS #11 error in key"), GNUTLS_E_PKCS11_KEY_ERROR),
+	ERROR_ENTRY(N_("PKCS #11 PIN expired"), GNUTLS_E_PKCS11_PIN_EXPIRED),
+	ERROR_ENTRY(N_("PKCS #11 PIN locked"), GNUTLS_E_PKCS11_PIN_LOCKED),
 	ERROR_ENTRY(N_("PKCS #11 error in session"),
 		    GNUTLS_E_PKCS11_SESSION_ERROR),
 	ERROR_ENTRY(N_("PKCS #11 error in signature"),
 		    GNUTLS_E_PKCS11_SIGNATURE_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 error in token"),
-		    GNUTLS_E_PKCS11_TOKEN_ERROR),
-	ERROR_ENTRY(N_("PKCS #11 user error"),
-		    GNUTLS_E_PKCS11_USER_ERROR),
-	ERROR_ENTRY(N_("The operation timed out"),
-		    GNUTLS_E_TIMEDOUT),
+	ERROR_ENTRY(N_("PKCS #11 error in token"), GNUTLS_E_PKCS11_TOKEN_ERROR),
+	ERROR_ENTRY(N_("PKCS #11 user error"), GNUTLS_E_PKCS11_USER_ERROR),
+	ERROR_ENTRY(N_("The operation timed out"), GNUTLS_E_TIMEDOUT),
 	ERROR_ENTRY(N_("The operation was cancelled due to user error"),
 		    GNUTLS_E_USER_ERROR),
 	ERROR_ENTRY(N_("No supported ECC curves were found"),
@@ -375,14 +357,14 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_ECC_UNSUPPORTED_CURVE),
 	ERROR_ENTRY(N_("The requested PKCS #11 object is not available"),
 		    GNUTLS_E_PKCS11_REQUESTED_OBJECT_NOT_AVAILBLE),
-	ERROR_ENTRY(N_
-		    ("The provided X.509 certificate list is not sorted (in subject to issuer order)"),
-		    GNUTLS_E_CERTIFICATE_LIST_UNSORTED),
+	ERROR_ENTRY(
+		N_("The provided X.509 certificate list is not sorted (in subject to issuer order)"),
+		GNUTLS_E_CERTIFICATE_LIST_UNSORTED),
 	ERROR_ENTRY(N_("The OCSP response is invalid"),
 		    GNUTLS_E_OCSP_RESPONSE_ERROR),
-	ERROR_ENTRY(N_
-		    ("The OCSP response provided doesn't match the available certificates"),
-		    GNUTLS_E_OCSP_MISMATCH_WITH_CERTS),
+	ERROR_ENTRY(
+		N_("The OCSP response provided doesn't match the available certificates"),
+		GNUTLS_E_OCSP_MISMATCH_WITH_CERTS),
 	ERROR_ENTRY(N_("There is no certificate status (OCSP)."),
 		    GNUTLS_E_NO_CERTIFICATE_STATUS),
 	ERROR_ENTRY(N_("Error in the system's randomness device."),
@@ -393,18 +375,18 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_SELF_TEST_ERROR),
 	ERROR_ENTRY(N_("There is no self test for this algorithm."),
 		    GNUTLS_E_NO_SELF_TEST),
-	ERROR_ENTRY(N_
-		    ("An error has been detected in the library and cannot continue operations."),
-		    GNUTLS_E_LIB_IN_ERROR_STATE),
+	ERROR_ENTRY(
+		N_("An error has been detected in the library and cannot continue operations."),
+		GNUTLS_E_LIB_IN_ERROR_STATE),
 	ERROR_ENTRY(N_("Error in sockets initialization."),
 		    GNUTLS_E_SOCKETS_INIT_ERROR),
 	ERROR_ENTRY(N_("Error in public key generation."),
 		    GNUTLS_E_PK_GENERATION_ERROR),
 	ERROR_ENTRY(N_("Invalid TLS extensions length field."),
 		    GNUTLS_E_UNEXPECTED_EXTENSIONS_LENGTH),
-	ERROR_ENTRY(N_
-		    ("Peer's certificate or username has changed during a rehandshake."),
-		    GNUTLS_E_SESSION_USER_ID_CHANGED),
+	ERROR_ENTRY(
+		N_("Peer's certificate or username has changed during a rehandshake."),
+		GNUTLS_E_SESSION_USER_ID_CHANGED),
 	ERROR_ENTRY(N_("The provided string has an embedded null."),
 		    GNUTLS_E_ASN1_EMBEDDED_NULL_IN_STRING),
 	ERROR_ENTRY(N_("Attempted handshake during false start."),
@@ -413,9 +395,9 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_UNRECOGNIZED_NAME),
 	ERROR_ENTRY(N_("There was an issue converting to or from UTF8."),
 		    GNUTLS_E_IDNA_ERROR),
-	ERROR_ENTRY(N_
-		    ("Cannot perform this action while handshake is in progress."),
-		    GNUTLS_E_UNAVAILABLE_DURING_HANDSHAKE),
+	ERROR_ENTRY(
+		N_("Cannot perform this action while handshake is in progress."),
+		GNUTLS_E_UNAVAILABLE_DURING_HANDSHAKE),
 	ERROR_ENTRY(N_("The public key is invalid."),
 		    GNUTLS_E_PK_INVALID_PUBKEY),
 	ERROR_ENTRY(N_("There are no validation parameters present."),
@@ -428,14 +410,16 @@ static const gnutls_error_entry error_entries[] = {
 		    GNUTLS_E_ASN1_TIME_ERROR),
 	ERROR_ENTRY(N_("The signature is incompatible with the public key."),
 		    GNUTLS_E_INCOMPATIBLE_SIG_WITH_KEY),
-	ERROR_ENTRY(N_
-		    ("One of the involved algorithms has insufficient security level."),
-		    GNUTLS_E_INSUFFICIENT_SECURITY),
+	ERROR_ENTRY(
+		N_("One of the involved algorithms has insufficient security level."),
+		GNUTLS_E_INSUFFICIENT_SECURITY),
 	ERROR_ENTRY(N_("No common key share with peer."),
 		    GNUTLS_E_NO_COMMON_KEY_SHARE),
 	ERROR_ENTRY(N_("The early data were rejected."),
 		    GNUTLS_E_EARLY_DATA_REJECTED),
-	{NULL, NULL, 0}
+	ERROR_ENTRY(N_("The encryption algorithm is not supported."),
+		    GNUTLS_E_UNSUPPORTED_ENCRYPTION_ALGORITHM),
+	{ NULL, NULL, 0 }
 };
 
 static const gnutls_error_entry non_fatal_error_entries[] = {
@@ -456,7 +440,7 @@ static const gnutls_error_entry non_fatal_error_entries[] = {
 	ERROR_ENTRY(N_("Re-authentication was requested by the peer."),
 		    GNUTLS_E_REAUTH_REQUEST),
 	/* Only non fatal (for handshake) errors here */
-	{NULL, NULL, 0}
+	{ NULL, NULL, 0 }
 };
 
 /**
@@ -600,8 +584,8 @@ void _gnutls_mpi_log(const char *prefix, bigint_t a)
 	res = _gnutls_mpi_print(a, NULL, &binlen);
 	if (res < 0 && res != GNUTLS_E_SHORT_MEMORY_BUFFER) {
 		gnutls_assert();
-		_gnutls_hard_log("MPI: %s can't print value (%d/%d)\n",
-				 prefix, res, (int)binlen);
+		_gnutls_hard_log("MPI: %s can't print value (%d/%d)\n", prefix,
+				 res, (int)binlen);
 		return;
 	}
 
@@ -623,8 +607,8 @@ void _gnutls_mpi_log(const char *prefix, bigint_t a)
 	res = _gnutls_mpi_print(a, binbuf, &binlen);
 	if (res != 0) {
 		gnutls_assert();
-		_gnutls_hard_log("MPI: %s can't print value (%d/%d)\n",
-				 prefix, res, (int)binlen);
+		_gnutls_hard_log("MPI: %s can't print value (%d/%d)\n", prefix,
+				 res, (int)binlen);
 		gnutls_free(binbuf);
 		return;
 	}
@@ -634,8 +618,8 @@ void _gnutls_mpi_log(const char *prefix, bigint_t a)
 
 	if (!hexbuf) {
 		gnutls_assert();
-		_gnutls_hard_log("MPI: %s out of memory (hex %d)\n",
-				 prefix, (int)hexlen);
+		_gnutls_hard_log("MPI: %s out of memory (hex %d)\n", prefix,
+				 (int)hexlen);
 		gnutls_free(binbuf);
 		return;
 	}
@@ -694,7 +678,7 @@ void _gnutls_audit_log(gnutls_session_t session, const char *fmt, ...)
 }
 
 #ifndef DEBUG
-# ifndef C99_MACROS
+#ifndef C99_MACROS
 
 /* Without C99 macros these functions have to
  * be called. This may affect performance.
@@ -704,5 +688,5 @@ void _gnutls_null_log(void *x, ...)
 	return;
 }
 
-# endif				/* C99_MACROS */
-#endif				/* DEBUG */
+#endif /* C99_MACROS */
+#endif /* DEBUG */
