@@ -21,45 +21,44 @@
  */
 
 #include "gnutls_int.h"
-#include <ext/srp.h>
+#include "ext/srp.h"
 
 #ifdef ENABLE_SRP
 
 #include "auth.h"
-#include <auth/srp_kx.h>
+#include "auth/srp_kx.h"
 #include "errors.h"
 #include "algorithms.h"
-#include <num.h>
-#include <hello_ext.h>
+#include "num.h"
+#include "hello_ext.h"
 
-static int _gnutls_srp_unpack(gnutls_buffer_st * ps,
-			      gnutls_ext_priv_data_t * _priv);
-static int _gnutls_srp_pack(gnutls_ext_priv_data_t epriv,
-			    gnutls_buffer_st * ps);
+static int _gnutls_srp_unpack(gnutls_buffer_st *ps,
+			      gnutls_ext_priv_data_t *_priv);
+static int _gnutls_srp_pack(gnutls_ext_priv_data_t epriv, gnutls_buffer_st *ps);
 static void _gnutls_srp_deinit_data(gnutls_ext_priv_data_t epriv);
-static int _gnutls_srp_recv_params(gnutls_session_t state,
-				   const uint8_t * data, size_t data_size);
+static int _gnutls_srp_recv_params(gnutls_session_t state, const uint8_t *data,
+				   size_t data_size);
 static int _gnutls_srp_send_params(gnutls_session_t state,
-				   gnutls_buffer_st * extdata);
+				   gnutls_buffer_st *extdata);
 
-const hello_ext_entry_st ext_mod_srp = {
-	.name = "SRP",
-	.tls_id = 12,
-	.gid = GNUTLS_EXTENSION_SRP,
-	.parse_type = GNUTLS_EXT_TLS,
-	.validity = GNUTLS_EXT_FLAG_TLS | GNUTLS_EXT_FLAG_DTLS | GNUTLS_EXT_FLAG_CLIENT_HELLO,
-	.recv_func = _gnutls_srp_recv_params,
-	.send_func = _gnutls_srp_send_params,
-	.pack_func = _gnutls_srp_pack,
-	.unpack_func = _gnutls_srp_unpack,
-	.deinit_func = _gnutls_srp_deinit_data,
-	.cannot_be_overriden = 1
-};
+const hello_ext_entry_st ext_mod_srp = { .name = "SRP",
+					 .tls_id = 12,
+					 .gid = GNUTLS_EXTENSION_SRP,
+					 .client_parse_point = GNUTLS_EXT_TLS,
+					 .server_parse_point = GNUTLS_EXT_TLS,
+					 .validity =
+						 GNUTLS_EXT_FLAG_TLS |
+						 GNUTLS_EXT_FLAG_DTLS |
+						 GNUTLS_EXT_FLAG_CLIENT_HELLO,
+					 .recv_func = _gnutls_srp_recv_params,
+					 .send_func = _gnutls_srp_send_params,
+					 .pack_func = _gnutls_srp_pack,
+					 .unpack_func = _gnutls_srp_unpack,
+					 .deinit_func = _gnutls_srp_deinit_data,
+					 .cannot_be_overriden = 1 };
 
-
-static int
-_gnutls_srp_recv_params(gnutls_session_t session, const uint8_t * data,
-			size_t data_size)
+static int _gnutls_srp_recv_params(gnutls_session_t session,
+				   const uint8_t *data, size_t data_size)
 {
 	uint8_t len;
 	gnutls_ext_priv_data_t epriv;
@@ -72,11 +71,6 @@ _gnutls_srp_recv_params(gnutls_session_t session, const uint8_t * data,
 			len = data[0];
 			DECR_LEN(data_size, len);
 
-			if (MAX_USERNAME_SIZE < len) {
-				gnutls_assert();
-				return GNUTLS_E_ILLEGAL_SRP_USERNAME;
-			}
-
 			priv = gnutls_calloc(1, sizeof(*priv));
 			if (priv == NULL) {
 				gnutls_assert();
@@ -92,8 +86,7 @@ _gnutls_srp_recv_params(gnutls_session_t session, const uint8_t * data,
 
 			epriv = priv;
 			_gnutls_hello_ext_set_priv(session,
-						     GNUTLS_EXTENSION_SRP,
-						     epriv);
+						   GNUTLS_EXTENSION_SRP, epriv);
 		}
 	}
 	return 0;
@@ -106,7 +99,8 @@ static unsigned have_srp_ciphersuites(gnutls_session_t session)
 
 	for (j = 0; j < session->internals.priorities->cs.size; j++) {
 		kx = session->internals.priorities->cs.entry[j]->kx_algorithm;
-		if (kx == GNUTLS_KX_SRP || kx == GNUTLS_KX_SRP_RSA || kx == GNUTLS_KX_SRP_DSS)
+		if (kx == GNUTLS_KX_SRP || kx == GNUTLS_KX_SRP_RSA ||
+		    kx == GNUTLS_KX_SRP_DSS)
 			return 1;
 	}
 
@@ -116,9 +110,8 @@ static unsigned have_srp_ciphersuites(gnutls_session_t session)
 /* returns data_size or a negative number on failure
  * data is allocated locally
  */
-static int
-_gnutls_srp_send_params(gnutls_session_t session,
-			gnutls_buffer_st * extdata)
+static int _gnutls_srp_send_params(gnutls_session_t session,
+				   gnutls_buffer_st *extdata)
 {
 	unsigned len;
 	int ret;
@@ -126,8 +119,8 @@ _gnutls_srp_send_params(gnutls_session_t session,
 	srp_ext_st *priv = NULL;
 	char *username = NULL, *password = NULL;
 	gnutls_srp_client_credentials_t cred =
-		    (gnutls_srp_client_credentials_t)
-		    _gnutls_get_cred(session, GNUTLS_CRD_SRP);
+		(gnutls_srp_client_credentials_t)_gnutls_get_cred(
+			session, GNUTLS_CRD_SRP);
 
 	if (session->security_parameters.entity != GNUTLS_CLIENT)
 		return 0;
@@ -144,14 +137,11 @@ _gnutls_srp_send_params(gnutls_session_t session,
 	if (priv == NULL)
 		return gnutls_assert_val(GNUTLS_E_MEMORY_ERROR);
 
-	if (cred->username != NULL) {	/* send username */
+	if (cred->username != NULL) { /* send username */
 		len = MIN(strlen(cred->username), 255);
 
-		ret =
-		    _gnutls_buffer_append_data_prefix(extdata, 8,
-						      cred->
-						      username,
-						      len);
+		ret = _gnutls_buffer_append_data_prefix(extdata, 8,
+							cred->username, len);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -170,18 +160,16 @@ _gnutls_srp_send_params(gnutls_session_t session,
 		}
 
 		epriv = priv;
-		_gnutls_hello_ext_set_priv(session,
-					     GNUTLS_EXTENSION_SRP,
-					     epriv);
+		_gnutls_hello_ext_set_priv(session, GNUTLS_EXTENSION_SRP,
+					   epriv);
 
 		return len + 1;
 	} else if (cred->get_function != NULL) {
 		/* Try the callback
 		 */
 
-		if (cred->
-		    get_function(session, &username, &password) < 0
-		    || username == NULL || password == NULL) {
+		if (cred->get_function(session, &username, &password) < 0 ||
+		    username == NULL || password == NULL) {
 			gnutls_assert();
 			return GNUTLS_E_ILLEGAL_SRP_USERNAME;
 		}
@@ -191,25 +179,22 @@ _gnutls_srp_send_params(gnutls_session_t session,
 		priv->username = username;
 		priv->password = password;
 
-		ret =
-		    _gnutls_buffer_append_data_prefix(extdata, 8,
-						      username,
-						      len);
+		ret = _gnutls_buffer_append_data_prefix(extdata, 8, username,
+							len);
 		if (ret < 0) {
 			ret = gnutls_assert_val(ret);
 			goto cleanup;
 		}
 
 		epriv = priv;
-		_gnutls_hello_ext_set_priv(session,
-					     GNUTLS_EXTENSION_SRP,
-					     epriv);
+		_gnutls_hello_ext_set_priv(session, GNUTLS_EXTENSION_SRP,
+					   epriv);
 
 		return len + 1;
 	}
 	return 0;
 
-      cleanup:
+cleanup:
 	gnutls_free(username);
 	gnutls_free(password);
 	gnutls_free(priv);
@@ -226,8 +211,7 @@ static void _gnutls_srp_deinit_data(gnutls_ext_priv_data_t epriv)
 	gnutls_free(priv);
 }
 
-static int
-_gnutls_srp_pack(gnutls_ext_priv_data_t epriv, gnutls_buffer_st * ps)
+static int _gnutls_srp_pack(gnutls_ext_priv_data_t epriv, gnutls_buffer_st *ps)
 {
 	srp_ext_st *priv = epriv;
 	int ret;
@@ -245,8 +229,8 @@ _gnutls_srp_pack(gnutls_ext_priv_data_t epriv, gnutls_buffer_st * ps)
 	return 0;
 }
 
-static int
-_gnutls_srp_unpack(gnutls_buffer_st * ps, gnutls_ext_priv_data_t * _priv)
+static int _gnutls_srp_unpack(gnutls_buffer_st *ps,
+			      gnutls_ext_priv_data_t *_priv)
 {
 	srp_ext_st *priv;
 	int ret;
@@ -263,19 +247,18 @@ _gnutls_srp_unpack(gnutls_buffer_st * ps, gnutls_ext_priv_data_t * _priv)
 	BUFFER_POP_DATUM(ps, &username);
 	BUFFER_POP_DATUM(ps, &password);
 
-	priv->username = (char *) username.data;
-	priv->password = (char *) password.data;
+	priv->username = (char *)username.data;
+	priv->password = (char *)password.data;
 
 	epriv = priv;
 	*_priv = epriv;
 
 	return 0;
 
-      error:
+error:
 	_gnutls_free_datum(&username);
 	_gnutls_free_datum(&password);
 	return ret;
 }
 
-
-#endif				/* ENABLE_SRP */
+#endif /* ENABLE_SRP */
