@@ -28,11 +28,11 @@
 #include "file.h"
 #include "inih/ini.h"
 #include "str.h"
-#include <fips.h>
+#include "fips.h"
 #include <gnutls/self-test.h>
 #include <stdio.h>
-#include <extras/hex.h>
-#include <random.h>
+#include "extras/hex.h"
+#include "random.h"
 
 #include "gthreads.h"
 
@@ -157,7 +157,11 @@ void _gnutls_fips_mode_reset_zombie(void)
 #define GNUTLS_LIBRARY_NAME GNUTLS_LIBRARY_SONAME
 #define NETTLE_LIBRARY_NAME NETTLE_LIBRARY_SONAME
 #define HOGWEED_LIBRARY_NAME HOGWEED_LIBRARY_SONAME
+
+/* GMP can be statically linked. */
+#ifdef GMP_LIBRARY_SONAME
 #define GMP_LIBRARY_NAME GMP_LIBRARY_SONAME
+#endif
 
 #define HMAC_SIZE 32
 #define HMAC_ALGO GNUTLS_MAC_SHA256
@@ -173,14 +177,18 @@ struct hmac_file {
 	struct hmac_entry gnutls;
 	struct hmac_entry nettle;
 	struct hmac_entry hogweed;
+#ifdef GMP_LIBRARY_SONAME
 	struct hmac_entry gmp;
+#endif
 };
 
 struct lib_paths {
 	char gnutls[GNUTLS_PATH_MAX];
 	char nettle[GNUTLS_PATH_MAX];
 	char hogweed[GNUTLS_PATH_MAX];
+#ifdef GMP_LIBRARY_SONAME
 	char gmp[GNUTLS_PATH_MAX];
+#endif
 };
 
 /*
@@ -244,8 +252,10 @@ static int handler(void *user, const char *section, const char *name,
 		return lib_handler(&p->nettle, section, name, value);
 	} else if (!strcmp(section, HOGWEED_LIBRARY_NAME)) {
 		return lib_handler(&p->hogweed, section, name, value);
+#ifdef GMP_LIBRARY_SONAME
 	} else if (!strcmp(section, GMP_LIBRARY_NAME)) {
 		return lib_handler(&p->gmp, section, name, value);
+#endif
 	} else {
 		return 0;
 	}
@@ -372,10 +382,12 @@ static int check_lib_hmac(struct hmac_entry *entry, const char *path)
 	if (gnutls_memcmp(entry->hmac, hmac, HMAC_SIZE)) {
 		_gnutls_debug_log("Calculated MAC for %s does not match\n",
 				  path);
+		gnutls_memset(hmac, 0, HMAC_SIZE);
 		return gnutls_assert_val(GNUTLS_E_PARSING_ERROR);
 	}
 	_gnutls_debug_log("Successfully verified MAC for %s\n", path);
 
+	gnutls_memset(hmac, 0, HMAC_SIZE);
 	return 0;
 }
 
@@ -393,8 +405,10 @@ static int callback(struct dl_phdr_info *info, size_t size, void *data)
 		_gnutls_str_cpy(paths->nettle, GNUTLS_PATH_MAX, path);
 	else if (!strcmp(soname, HOGWEED_LIBRARY_SONAME))
 		_gnutls_str_cpy(paths->hogweed, GNUTLS_PATH_MAX, path);
+#ifdef GMP_LIBRARY_SONAME
 	else if (!strcmp(soname, GMP_LIBRARY_SONAME))
 		_gnutls_str_cpy(paths->gmp, GNUTLS_PATH_MAX, path);
+#endif
 	return 0;
 }
 
@@ -415,10 +429,12 @@ static int load_lib_paths(struct lib_paths *paths)
 		_gnutls_debug_log("Hogweed library path was not found\n");
 		return gnutls_assert_val(GNUTLS_E_FILE_ERROR);
 	}
+#ifdef GMP_LIBRARY_SONAME
 	if (paths->gmp[0] == '\0') {
 		_gnutls_debug_log("Gmp library path was not found\n");
 		return gnutls_assert_val(GNUTLS_E_FILE_ERROR);
 	}
+#endif
 
 	return GNUTLS_E_SUCCESS;
 }
@@ -471,9 +487,11 @@ static int check_binary_integrity(void)
 	ret = check_lib_hmac(&hmac.hogweed, paths.hogweed);
 	if (ret < 0)
 		return ret;
+#ifdef GMP_LIBRARY_SONAME
 	ret = check_lib_hmac(&hmac.gmp, paths.gmp);
 	if (ret < 0)
 		return ret;
+#endif
 
 	return 0;
 }
@@ -576,9 +594,11 @@ int _gnutls_fips_perform_self_checks2(void)
 	}
 
 	/* PK */
-	ret = gnutls_pk_self_test(0, GNUTLS_PK_RSA);
-	if (ret < 0) {
-		return gnutls_assert_val(GNUTLS_E_SELF_TEST_ERROR);
+	if (_gnutls_config_is_rsa_pkcs1_encrypt_allowed()) {
+		ret = gnutls_pk_self_test(0, GNUTLS_PK_RSA);
+		if (ret < 0) {
+			return gnutls_assert_val(GNUTLS_E_SELF_TEST_ERROR);
+		}
 	}
 
 	ret = gnutls_pk_self_test(0, GNUTLS_PK_DSA);
