@@ -25,26 +25,25 @@
 #include <stdio.h>
 #include <string.h>
 #include "errors.h"
-#include <datum.h>
-#include <pkcs11_int.h>
+#include "datum.h"
+#include "pkcs11_int.h"
 #include <gnutls/abstract.h>
-#include <pk.h>
-#include <x509_int.h>
-#include <tls-sig.h>
-#include <algorithms.h>
-#include <fips.h>
-#include <system-keys.h>
+#include "pk.h"
+#include "x509_int.h"
+#include "tls-sig.h"
+#include "algorithms.h"
+#include "fips.h"
+#include "system-keys.h"
 #include "urls.h"
 #include "tpm2.h"
 #include "pkcs11_int.h"
-#include <abstract_int.h>
+#include "abstract_int.h"
 
-static int
-privkey_sign_prehashed(gnutls_privkey_t signer,
-		       const gnutls_sign_entry_st *se,
-		       const gnutls_datum_t * hash_data,
-		       gnutls_datum_t * signature,
-		       gnutls_x509_spki_st * params);
+static int privkey_sign_prehashed(gnutls_privkey_t signer,
+				  const gnutls_sign_entry_st *se,
+				  const gnutls_datum_t *hash_data,
+				  gnutls_datum_t *signature,
+				  gnutls_x509_spki_st *params);
 
 /**
  * gnutls_privkey_get_type:
@@ -79,11 +78,14 @@ gnutls_privkey_type_t gnutls_privkey_get_type(gnutls_privkey_t key)
  *
  * Since: 3.5.0
  **/
-int gnutls_privkey_get_seed(gnutls_privkey_t key, gnutls_digest_algorithm_t *digest, void *seed, size_t *seed_size)
+int gnutls_privkey_get_seed(gnutls_privkey_t key,
+			    gnutls_digest_algorithm_t *digest, void *seed,
+			    size_t *seed_size)
 {
 	if (key->type != GNUTLS_PRIVKEY_X509)
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
-	return gnutls_x509_privkey_get_seed(key->key.x509, digest, seed, seed_size);
+	return gnutls_x509_privkey_get_seed(key->key.x509, digest, seed,
+					    seed_size);
 }
 
 /**
@@ -101,11 +103,14 @@ int gnutls_privkey_get_seed(gnutls_privkey_t key, gnutls_digest_algorithm_t *dig
  *
  * Since: 3.5.0
  **/
-int gnutls_privkey_verify_seed(gnutls_privkey_t key, gnutls_digest_algorithm_t digest, const void *seed, size_t seed_size)
+int gnutls_privkey_verify_seed(gnutls_privkey_t key,
+			       gnutls_digest_algorithm_t digest,
+			       const void *seed, size_t seed_size)
 {
 	if (key->type != GNUTLS_PRIVKEY_X509)
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
-	return gnutls_x509_privkey_verify_seed(key->key.x509, digest, seed, seed_size);
+	return gnutls_x509_privkey_verify_seed(key->key.x509, digest, seed,
+					       seed_size);
 }
 
 /**
@@ -145,12 +150,11 @@ int gnutls_privkey_get_pk_algorithm(gnutls_privkey_t key, unsigned int *bits)
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
-
 }
 
-static int
-privkey_to_pubkey(gnutls_pk_algorithm_t pk,
-		  const gnutls_pk_params_st * priv, gnutls_pk_params_st * pub)
+static int privkey_to_pubkey(gnutls_pk_algorithm_t pk,
+			     const gnutls_pk_params_st *priv,
+			     gnutls_pk_params_st *pub)
 {
 	int ret;
 
@@ -159,10 +163,15 @@ privkey_to_pubkey(gnutls_pk_algorithm_t pk,
 	pub->curve = priv->curve;
 	pub->gost_params = priv->gost_params;
 	pub->qbits = priv->qbits;
-	memcpy(&pub->spki, &priv->spki, sizeof(gnutls_x509_spki_st));
+	ret = _gnutls_x509_spki_copy(&pub->spki, &priv->spki);
+	if (ret < 0) {
+		gnutls_assert();
+		goto cleanup;
+	}
 
 	switch (pk) {
 	case GNUTLS_PK_RSA_PSS:
+	case GNUTLS_PK_RSA_OAEP:
 	case GNUTLS_PK_RSA:
 		pub->params[0] = _gnutls_mpi_copy(priv->params[0]);
 		pub->params[1] = _gnutls_mpi_copy(priv->params[1]);
@@ -177,20 +186,45 @@ privkey_to_pubkey(gnutls_pk_algorithm_t pk,
 
 		break;
 	case GNUTLS_PK_DSA:
-		pub->params[0] = _gnutls_mpi_copy(priv->params[0]);
-		pub->params[1] = _gnutls_mpi_copy(priv->params[1]);
-		pub->params[2] = _gnutls_mpi_copy(priv->params[2]);
-		pub->params[3] = _gnutls_mpi_copy(priv->params[3]);
+		pub->params[DSA_P] = _gnutls_mpi_copy(priv->params[DSA_P]);
+		pub->params[DSA_Q] = _gnutls_mpi_copy(priv->params[DSA_Q]);
+		pub->params[DSA_G] = _gnutls_mpi_copy(priv->params[DSA_G]);
+		pub->params[DSA_Y] = _gnutls_mpi_copy(priv->params[DSA_Y]);
 
 		pub->params_nr = DSA_PUBLIC_PARAMS;
 
-		if (pub->params[0] == NULL || pub->params[1] == NULL ||
-		    pub->params[2] == NULL || pub->params[3] == NULL) {
+		if (pub->params[DSA_P] == NULL || pub->params[DSA_Q] == NULL ||
+		    pub->params[DSA_G] == NULL || pub->params[DSA_Y] == NULL) {
 			gnutls_assert();
 			ret = GNUTLS_E_MEMORY_ERROR;
 			goto cleanup;
 		}
 
+		break;
+	case GNUTLS_PK_DH:
+		pub->params[DH_P] = _gnutls_mpi_copy(priv->params[DH_P]);
+		pub->params[DH_G] = _gnutls_mpi_copy(priv->params[DH_G]);
+		pub->params[DH_Y] = _gnutls_mpi_copy(priv->params[DH_Y]);
+
+		if (pub->params[DH_P] == NULL || pub->params[DH_G] == NULL ||
+		    pub->params[DH_Y] == NULL) {
+			gnutls_assert();
+			ret = GNUTLS_E_MEMORY_ERROR;
+			goto cleanup;
+		}
+
+		if (priv->params[DH_Q]) {
+			pub->params[DH_Q] =
+				_gnutls_mpi_copy(priv->params[DH_Q]);
+			if (pub->params[DH_Q] == NULL) {
+				gnutls_assert();
+				ret = GNUTLS_E_MEMORY_ERROR;
+				goto cleanup;
+			}
+		}
+
+		pub->params_nr = DH_PUBLIC_PARAMS;
+
 		break;
 	case GNUTLS_PK_ECDSA:
 		pub->params[ECC_X] = _gnutls_mpi_copy(priv->params[ECC_X]);
@@ -209,7 +243,8 @@ privkey_to_pubkey(gnutls_pk_algorithm_t pk,
 	case GNUTLS_PK_EDDSA_ED448:
 	case GNUTLS_PK_ECDH_X25519:
 	case GNUTLS_PK_ECDH_X448:
-		ret = _gnutls_set_datum(&pub->raw_pub, priv->raw_pub.data, priv->raw_pub.size);
+		ret = _gnutls_set_datum(&pub->raw_pub, priv->raw_pub.data,
+					priv->raw_pub.size);
 		if (ret < 0)
 			return gnutls_assert_val(ret);
 
@@ -222,7 +257,8 @@ privkey_to_pubkey(gnutls_pk_algorithm_t pk,
 
 		pub->params_nr = GOST_PUBLIC_PARAMS;
 
-		if (pub->params[GOST_X] == NULL || pub->params[GOST_Y] == NULL) {
+		if (pub->params[GOST_X] == NULL ||
+		    pub->params[GOST_Y] == NULL) {
 			gnutls_assert();
 			ret = GNUTLS_E_MEMORY_ERROR;
 			goto cleanup;
@@ -235,15 +271,14 @@ privkey_to_pubkey(gnutls_pk_algorithm_t pk,
 	}
 
 	return 0;
- cleanup:
+cleanup:
 	gnutls_pk_params_release(pub);
 	return ret;
 }
 
 /* Returns the public key of the private key (if possible)
  */
-int
-_gnutls_privkey_get_mpis(gnutls_privkey_t key, gnutls_pk_params_st * params)
+int _gnutls_privkey_get_mpis(gnutls_privkey_t key, gnutls_pk_params_st *params)
 {
 	int ret;
 
@@ -263,13 +298,12 @@ _gnutls_privkey_get_mpis(gnutls_privkey_t key, gnutls_pk_params_st * params)
 		gnutls_pubkey_deinit(pubkey);
 
 		break;
-		}
+	}
 #endif
 	default:
 		if (key->key.ext.pk_params_func) {
-			ret = key->key.ext.pk_params_func(key,
-							  key->key.ext.userdata,
-							  params);
+			ret = key->key.ext.pk_params_func(
+				key, key->key.ext.userdata, params);
 			if (ret < 0)
 				return gnutls_assert_val(ret);
 			return ret;
@@ -281,9 +315,8 @@ _gnutls_privkey_get_mpis(gnutls_privkey_t key, gnutls_pk_params_st * params)
 	return ret;
 }
 
-int
-_gnutls_privkey_get_public_mpis(gnutls_privkey_t key,
-				gnutls_pk_params_st * params)
+int _gnutls_privkey_get_public_mpis(gnutls_privkey_t key,
+				    gnutls_pk_params_st *params)
 {
 	int ret;
 	gnutls_pk_params_st tmp1;
@@ -305,9 +338,8 @@ _gnutls_privkey_get_public_mpis(gnutls_privkey_t key,
 }
 
 /* This function retrieves default sign parameters from KEY. */
-int
-_gnutls_privkey_get_spki_params(gnutls_privkey_t key,
-				gnutls_x509_spki_st * params)
+int _gnutls_privkey_get_spki_params(gnutls_privkey_t key,
+				    gnutls_x509_spki_st *params)
 {
 	switch (key->type) {
 #ifdef ENABLE_PKCS11
@@ -317,8 +349,8 @@ _gnutls_privkey_get_spki_params(gnutls_privkey_t key,
 	case GNUTLS_PRIVKEY_EXT:
 		break;
 	case GNUTLS_PRIVKEY_X509:
-		_gnutls_x509_privkey_get_spki_params(key->key.x509, params);
-		return 0;
+		return _gnutls_x509_privkey_get_spki_params(key->key.x509,
+							    params);
 	default:
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
@@ -336,12 +368,11 @@ _gnutls_privkey_get_spki_params(gnutls_privkey_t key,
  * After calling this function the params structure will
  * be initialized even if the original SubjectPublicKeyInfo was empty.
  */
-int
-_gnutls_privkey_update_spki_params(gnutls_privkey_t key,
-				 gnutls_pk_algorithm_t pk,
-				 gnutls_digest_algorithm_t dig,
-				 unsigned flags,
-				 gnutls_x509_spki_st *params)
+int _gnutls_privkey_update_spki_params(gnutls_privkey_t key,
+				       gnutls_pk_algorithm_t pk,
+				       gnutls_digest_algorithm_t dig,
+				       unsigned flags,
+				       gnutls_x509_spki_st *params)
 {
 	unsigned salt_size = 0;
 	unsigned bits = 0;
@@ -355,7 +386,7 @@ _gnutls_privkey_update_spki_params(gnutls_privkey_t key,
 
 	key_pk = gnutls_privkey_get_pk_algorithm(key, &bits);
 	if ((key_pk != pk) &&
-	      !(key_pk == GNUTLS_PK_RSA && pk == GNUTLS_PK_RSA_PSS)) {
+	    !(key_pk == GNUTLS_PK_RSA && pk == GNUTLS_PK_RSA_PSS)) {
 		gnutls_assert();
 		return GNUTLS_E_CONSTRAINT_ERROR;
 	}
@@ -371,8 +402,10 @@ _gnutls_privkey_update_spki_params(gnutls_privkey_t key,
 		if (params->pk == GNUTLS_PK_RSA)
 			salt_size = 0;
 		else if (params->pk == GNUTLS_PK_RSA_PSS) {
-			if (params->rsa_pss_dig != GNUTLS_DIG_UNKNOWN && dig != params->rsa_pss_dig) {
-				return gnutls_assert_val(GNUTLS_E_CONSTRAINT_ERROR);
+			if (params->rsa_pss_dig != GNUTLS_DIG_UNKNOWN &&
+			    dig != params->rsa_pss_dig) {
+				return gnutls_assert_val(
+					GNUTLS_E_CONSTRAINT_ERROR);
 			}
 
 			salt_size = params->salt_size;
@@ -381,12 +414,14 @@ _gnutls_privkey_update_spki_params(gnutls_privkey_t key,
 		if (flags & GNUTLS_PRIVKEY_FLAG_REPRODUCIBLE)
 			params->salt_size = 0;
 		else {
-			ret = _gnutls_find_rsa_pss_salt_size(bits, me, salt_size);
+			ret = _gnutls_find_rsa_pss_salt_size(bits, me,
+							     salt_size);
 			if (ret < 0)
 				return gnutls_assert_val(ret);
 			if (flags & GNUTLS_PRIVKEY_FLAG_RSA_PSS_FIXED_SALT_LENGTH &&
 			    (size_t)ret != _gnutls_hash_get_algo_len(me)) {
-				return gnutls_assert_val(GNUTLS_E_CONSTRAINT_ERROR);
+				return gnutls_assert_val(
+					GNUTLS_E_CONSTRAINT_ERROR);
 			}
 			params->salt_size = ret;
 		}
@@ -418,8 +453,9 @@ _gnutls_privkey_update_spki_params(gnutls_privkey_t key,
  *
  * Since: 2.12.0
  **/
-int gnutls_privkey_init(gnutls_privkey_t * key)
+int gnutls_privkey_init(gnutls_privkey_t *key)
 {
+	*key = NULL;
 	FAIL_IF_LIB_ERROR;
 
 	*key = gnutls_calloc(1, sizeof(struct gnutls_privkey_st));
@@ -444,8 +480,8 @@ void gnutls_privkey_deinit(gnutls_privkey_t key)
 	if (key == NULL)
 		return;
 
-	if (key->flags & GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE
-	    || key->flags & GNUTLS_PRIVKEY_IMPORT_COPY)
+	if (key->flags & GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE ||
+	    key->flags & GNUTLS_PRIVKEY_IMPORT_COPY)
 		switch (key->type) {
 #ifdef ENABLE_PKCS11
 		case GNUTLS_PRIVKEY_PKCS11:
@@ -507,9 +543,9 @@ static int check_if_clean(gnutls_privkey_t key)
  *
  * Since: 2.12.0
  **/
-int
-gnutls_privkey_import_pkcs11(gnutls_privkey_t pkey,
-			     gnutls_pkcs11_privkey_t key, unsigned int flags)
+int gnutls_privkey_import_pkcs11(gnutls_privkey_t pkey,
+				 gnutls_pkcs11_privkey_t key,
+				 unsigned int flags)
 {
 	int ret;
 
@@ -540,7 +576,7 @@ gnutls_privkey_import_pkcs11(gnutls_privkey_t pkey,
  * @key: A key of type #gnutls_pubkey_t
  * @url: A PKCS 11 url
  *
- * This function will import a PKCS 11 private key to a #gnutls_private_key_t
+ * This function will import a PKCS 11 private key to a #gnutls_privkey_t
  * type.
  *
  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, otherwise a
@@ -555,8 +591,8 @@ int gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key, const char *url)
 }
 #endif
 
-static
-int _gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key, const char *url, unsigned flags)
+static int _gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key,
+					     const char *url, unsigned flags)
 {
 	gnutls_pkcs11_privkey_t pkey;
 	int ret;
@@ -577,9 +613,8 @@ int _gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key, const char *url, uns
 		goto cleanup;
 	}
 
-	ret =
-	    gnutls_privkey_import_pkcs11(key, pkey,
-					 GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
+	ret = gnutls_privkey_import_pkcs11(key, pkey,
+					   GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -587,7 +622,7 @@ int _gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key, const char *url, uns
 
 	return 0;
 
- cleanup:
+cleanup:
 	gnutls_pkcs11_privkey_deinit(pkey);
 
 	return ret;
@@ -608,12 +643,12 @@ int _gnutls_privkey_import_pkcs11_url(gnutls_privkey_t key, const char *url, uns
  *
  * Since: 3.4.0
  */
-int
-gnutls_privkey_export_pkcs11(gnutls_privkey_t pkey,
-			     gnutls_pkcs11_privkey_t *key)
+int gnutls_privkey_export_pkcs11(gnutls_privkey_t pkey,
+				 gnutls_pkcs11_privkey_t *key)
 {
 	int ret;
 
+	*key = NULL;
 	if (pkey->type != GNUTLS_PRIVKEY_PKCS11) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
@@ -633,7 +668,7 @@ gnutls_privkey_export_pkcs11(gnutls_privkey_t pkey,
 
 	return 0;
 }
-#endif				/* ENABLE_PKCS11 */
+#endif /* ENABLE_PKCS11 */
 
 /**
  * gnutls_privkey_import_ext:
@@ -660,20 +695,19 @@ gnutls_privkey_export_pkcs11(gnutls_privkey_t pkey,
  *
  * Since: 3.0
  **/
-int
-gnutls_privkey_import_ext(gnutls_privkey_t pkey,
-			  gnutls_pk_algorithm_t pk,
-			  void *userdata,
-			  gnutls_privkey_sign_func sign_func,
-			  gnutls_privkey_decrypt_func decrypt_func,
-			  unsigned int flags)
+int gnutls_privkey_import_ext(gnutls_privkey_t pkey, gnutls_pk_algorithm_t pk,
+			      void *userdata,
+			      gnutls_privkey_sign_func sign_func,
+			      gnutls_privkey_decrypt_func decrypt_func,
+			      unsigned int flags)
 {
 	return gnutls_privkey_import_ext2(pkey, pk, userdata, sign_func,
 					  decrypt_func, NULL, flags);
 }
 
-#define PK_IS_OK_FOR_EXT2(pk) \
-	((pk == GNUTLS_PK_RSA) || (pk == GNUTLS_PK_ECDSA) || (pk == GNUTLS_PK_DSA))
+#define PK_IS_OK_FOR_EXT2(pk)                                \
+	((pk == GNUTLS_PK_RSA) || (pk == GNUTLS_PK_ECDSA) || \
+	 (pk == GNUTLS_PK_DSA))
 
 /**
  * gnutls_privkey_import_ext2:
@@ -702,14 +736,11 @@ gnutls_privkey_import_ext(gnutls_privkey_t pkey,
  *
  * Since: 3.1
  **/
-int
-gnutls_privkey_import_ext2(gnutls_privkey_t pkey,
-			   gnutls_pk_algorithm_t pk,
-			   void *userdata,
-			   gnutls_privkey_sign_func sign_fn,
-			   gnutls_privkey_decrypt_func decrypt_fn,
-			   gnutls_privkey_deinit_func deinit_fn,
-			   unsigned int flags)
+int gnutls_privkey_import_ext2(gnutls_privkey_t pkey, gnutls_pk_algorithm_t pk,
+			       void *userdata, gnutls_privkey_sign_func sign_fn,
+			       gnutls_privkey_decrypt_func decrypt_fn,
+			       gnutls_privkey_deinit_func deinit_fn,
+			       unsigned int flags)
 {
 	int ret;
 
@@ -769,14 +800,12 @@ gnutls_privkey_import_ext2(gnutls_privkey_t pkey,
  *
  * Since: 3.4.0
  **/
-int
-gnutls_privkey_import_ext3(gnutls_privkey_t pkey,
-			   void *userdata,
-			   gnutls_privkey_sign_func sign_fn,
-			   gnutls_privkey_decrypt_func decrypt_fn,
-			   gnutls_privkey_deinit_func deinit_fn,
-			   gnutls_privkey_info_func info_fn,
-			   unsigned int flags)
+int gnutls_privkey_import_ext3(gnutls_privkey_t pkey, void *userdata,
+			       gnutls_privkey_sign_func sign_fn,
+			       gnutls_privkey_decrypt_func decrypt_fn,
+			       gnutls_privkey_deinit_func deinit_fn,
+			       gnutls_privkey_info_func info_fn,
+			       unsigned int flags)
 {
 	int ret;
 
@@ -800,7 +829,8 @@ gnutls_privkey_import_ext3(gnutls_privkey_t pkey,
 	pkey->type = GNUTLS_PRIVKEY_EXT;
 	pkey->flags = flags;
 
-	pkey->pk_algorithm = pkey->key.ext.info_func(pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO, pkey->key.ext.userdata);
+	pkey->pk_algorithm = pkey->key.ext.info_func(
+		pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO, pkey->key.ext.userdata);
 
 	if (!PK_IS_OK_FOR_EXT2(pkey->pk_algorithm))
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
@@ -858,15 +888,13 @@ gnutls_privkey_import_ext3(gnutls_privkey_t pkey,
  *
  * Since: 3.6.0
  **/
-int
-gnutls_privkey_import_ext4(gnutls_privkey_t pkey,
-                           void *userdata,
-                           gnutls_privkey_sign_data_func sign_data_fn,
-                           gnutls_privkey_sign_hash_func sign_hash_fn,
-                           gnutls_privkey_decrypt_func decrypt_fn,
-                           gnutls_privkey_deinit_func deinit_fn,
-                           gnutls_privkey_info_func info_fn,
-                           unsigned int flags)
+int gnutls_privkey_import_ext4(gnutls_privkey_t pkey, void *userdata,
+			       gnutls_privkey_sign_data_func sign_data_fn,
+			       gnutls_privkey_sign_hash_func sign_hash_fn,
+			       gnutls_privkey_decrypt_func decrypt_fn,
+			       gnutls_privkey_deinit_func deinit_fn,
+			       gnutls_privkey_info_func info_fn,
+			       unsigned int flags)
 {
 	int ret;
 
@@ -891,9 +919,11 @@ gnutls_privkey_import_ext4(gnutls_privkey_t pkey,
 	pkey->type = GNUTLS_PRIVKEY_EXT;
 	pkey->flags = flags;
 
-	pkey->pk_algorithm = pkey->key.ext.info_func(pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO, pkey->key.ext.userdata);
+	pkey->pk_algorithm = pkey->key.ext.info_func(
+		pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO, pkey->key.ext.userdata);
 
-	ret = pkey->key.ext.info_func(pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO_BITS, pkey->key.ext.userdata);
+	ret = pkey->key.ext.info_func(pkey, GNUTLS_PRIVKEY_INFO_PK_ALGO_BITS,
+				      pkey->key.ext.userdata);
 	if (ret >= 0)
 		pkey->key.ext.bits = ret;
 
@@ -924,9 +954,8 @@ gnutls_privkey_import_ext4(gnutls_privkey_t pkey,
  *
  * Since: 2.12.0
  **/
-int
-gnutls_privkey_import_x509(gnutls_privkey_t pkey,
-			   gnutls_x509_privkey_t key, unsigned int flags)
+int gnutls_privkey_import_x509(gnutls_privkey_t pkey, gnutls_x509_privkey_t key,
+			       unsigned int flags)
 {
 	int ret;
 
@@ -971,12 +1000,12 @@ gnutls_privkey_import_x509(gnutls_privkey_t pkey,
  *
  * Since: 3.4.0
  */
-int
-gnutls_privkey_export_x509(gnutls_privkey_t pkey,
-			   gnutls_x509_privkey_t *key)
+int gnutls_privkey_export_x509(gnutls_privkey_t pkey,
+			       gnutls_x509_privkey_t *key)
 {
 	int ret;
 
+	*key = NULL;
 	if (pkey->type != GNUTLS_PRIVKEY_X509) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
@@ -1030,10 +1059,8 @@ gnutls_privkey_export_x509(gnutls_privkey_t pkey,
  *
  * Since: 3.3.0
  **/
-int
-gnutls_privkey_generate(gnutls_privkey_t pkey,
-			gnutls_pk_algorithm_t algo, unsigned int bits,
-			unsigned int flags)
+int gnutls_privkey_generate(gnutls_privkey_t pkey, gnutls_pk_algorithm_t algo,
+			    unsigned int bits, unsigned int flags)
 {
 	return gnutls_privkey_generate2(pkey, algo, bits, flags, NULL, 0);
 }
@@ -1078,10 +1105,10 @@ gnutls_privkey_generate(gnutls_privkey_t pkey,
  *
  * Since: 3.5.0
  **/
-int
-gnutls_privkey_generate2(gnutls_privkey_t pkey,
-			 gnutls_pk_algorithm_t algo, unsigned int bits,
-			 unsigned int flags, const gnutls_keygen_data_st *data, unsigned data_size)
+int gnutls_privkey_generate2(gnutls_privkey_t pkey, gnutls_pk_algorithm_t algo,
+			     unsigned int bits, unsigned int flags,
+			     const gnutls_keygen_data_st *data,
+			     unsigned data_size)
 {
 	int ret;
 
@@ -1089,7 +1116,8 @@ gnutls_privkey_generate2(gnutls_privkey_t pkey,
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
-	ret = gnutls_x509_privkey_generate2(pkey->key.x509, algo, bits, flags, data, data_size);
+	ret = gnutls_x509_privkey_generate2(pkey->key.x509, algo, bits, flags,
+					    data, data_size);
 	if (ret < 0) {
 		gnutls_x509_privkey_deinit(pkey->key.x509);
 		pkey->key.x509 = NULL;
@@ -1124,12 +1152,10 @@ gnutls_privkey_generate2(gnutls_privkey_t pkey,
  *
  * Since: 2.12.0
  **/
-int
-gnutls_privkey_sign_data(gnutls_privkey_t signer,
-			 gnutls_digest_algorithm_t hash,
-			 unsigned int flags,
-			 const gnutls_datum_t * data,
-			 gnutls_datum_t * signature)
+int gnutls_privkey_sign_data(gnutls_privkey_t signer,
+			     gnutls_digest_algorithm_t hash, unsigned int flags,
+			     const gnutls_datum_t *data,
+			     gnutls_datum_t *signature)
 {
 	int ret;
 	gnutls_x509_spki_st params;
@@ -1144,7 +1170,7 @@ gnutls_privkey_sign_data(gnutls_privkey_t signer,
 	}
 
 	ret = _gnutls_privkey_update_spki_params(signer, signer->pk_algorithm,
-					         hash, flags, &params);
+						 hash, flags, &params);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -1152,7 +1178,9 @@ gnutls_privkey_sign_data(gnutls_privkey_t signer,
 
 	FIX_SIGN_PARAMS(params, flags, hash);
 
-	return privkey_sign_and_hash_data(signer, _gnutls_pk_to_sign_entry(params.pk, hash), data, signature, &params);
+	return privkey_sign_and_hash_data(
+		signer, _gnutls_pk_to_sign_entry(params.pk, hash), data,
+		signature, &params);
 }
 
 /**
@@ -1173,12 +1201,10 @@ gnutls_privkey_sign_data(gnutls_privkey_t signer,
  *
  * Since: 3.6.0
  **/
-int
-gnutls_privkey_sign_data2(gnutls_privkey_t signer,
-			  gnutls_sign_algorithm_t algo,
-			  unsigned int flags,
-			  const gnutls_datum_t * data,
-			  gnutls_datum_t * signature)
+int gnutls_privkey_sign_data2(gnutls_privkey_t signer,
+			      gnutls_sign_algorithm_t algo, unsigned int flags,
+			      const gnutls_datum_t *data,
+			      gnutls_datum_t *signature)
 {
 	int ret;
 	gnutls_x509_spki_st params;
@@ -1198,7 +1224,7 @@ gnutls_privkey_sign_data2(gnutls_privkey_t signer,
 	}
 
 	ret = _gnutls_privkey_update_spki_params(signer, se->pk, se->hash,
-					         flags, &params);
+						 flags, &params);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -1234,12 +1260,10 @@ gnutls_privkey_sign_data2(gnutls_privkey_t signer,
  *
  * Since: 3.6.0
  **/
-int
-gnutls_privkey_sign_hash2(gnutls_privkey_t signer,
-			  gnutls_sign_algorithm_t algo,
-			  unsigned int flags,
-			  const gnutls_datum_t * hash_data,
-			  gnutls_datum_t * signature)
+int gnutls_privkey_sign_hash2(gnutls_privkey_t signer,
+			      gnutls_sign_algorithm_t algo, unsigned int flags,
+			      const gnutls_datum_t *hash_data,
+			      gnutls_datum_t *signature)
 {
 	int ret;
 	gnutls_x509_spki_st params;
@@ -1264,7 +1288,7 @@ gnutls_privkey_sign_hash2(gnutls_privkey_t signer,
 	}
 
 	ret = _gnutls_privkey_update_spki_params(signer, se->pk, se->hash,
-					         flags, &params);
+						 flags, &params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1274,7 +1298,7 @@ gnutls_privkey_sign_hash2(gnutls_privkey_t signer,
 
 	ret = privkey_sign_prehashed(signer, se, hash_data, signature, &params);
 
- cleanup:
+cleanup:
 	if (ret < 0) {
 		_gnutls_switch_fips_state(GNUTLS_FIPS140_OP_ERROR);
 	} else {
@@ -1283,12 +1307,11 @@ gnutls_privkey_sign_hash2(gnutls_privkey_t signer,
 	return ret;
 }
 
-int
-privkey_sign_and_hash_data(gnutls_privkey_t signer,
-			   const gnutls_sign_entry_st *se,
-			   const gnutls_datum_t * data,
-			   gnutls_datum_t * signature,
-			   gnutls_x509_spki_st * params)
+int privkey_sign_and_hash_data(gnutls_privkey_t signer,
+			       const gnutls_sign_entry_st *se,
+			       const gnutls_datum_t *data,
+			       gnutls_datum_t *signature,
+			       gnutls_x509_spki_st *params)
 {
 	int ret;
 	gnutls_datum_t digest;
@@ -1298,7 +1321,8 @@ privkey_sign_and_hash_data(gnutls_privkey_t signer,
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
 	if (_gnutls_pk_is_not_prehashed(se->pk)) {
-		return privkey_sign_raw_data(signer, se, data, signature, params);
+		return privkey_sign_raw_data(signer, se, data, signature,
+					     params);
 	}
 
 	me = hash_to_entry(se->hash);
@@ -1327,12 +1351,11 @@ privkey_sign_and_hash_data(gnutls_privkey_t signer,
 
 	return 0;
 
- cleanup:
+cleanup:
 	_gnutls_free_datum(&digest);
 	return ret;
 }
 
-
 /**
  * gnutls_privkey_sign_hash:
  * @signer: Holds the signer's key
@@ -1361,12 +1384,11 @@ privkey_sign_and_hash_data(gnutls_privkey_t signer,
  *
  * Since: 2.12.0
  **/
-int
-gnutls_privkey_sign_hash(gnutls_privkey_t signer,
-			 gnutls_digest_algorithm_t hash_algo,
-			 unsigned int flags,
-			 const gnutls_datum_t * hash_data,
-			 gnutls_datum_t * signature)
+int gnutls_privkey_sign_hash(gnutls_privkey_t signer,
+			     gnutls_digest_algorithm_t hash_algo,
+			     unsigned int flags,
+			     const gnutls_datum_t *hash_data,
+			     gnutls_datum_t *signature)
 {
 	int ret;
 	gnutls_x509_spki_st params;
@@ -1379,7 +1401,7 @@ gnutls_privkey_sign_hash(gnutls_privkey_t signer,
 	}
 
 	ret = _gnutls_privkey_update_spki_params(signer, signer->pk_algorithm,
-					       hash_algo, flags, &params);
+						 hash_algo, flags, &params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1388,11 +1410,13 @@ gnutls_privkey_sign_hash(gnutls_privkey_t signer,
 	/* legacy callers of this API could use a hash algorithm of 0 (unknown)
 	 * to indicate raw hashing. As we now always want to know the signing
 	 * algorithm involved, we try discovering the hash algorithm. */
-	if (hash_algo == 0 && (params.pk == GNUTLS_PK_DSA || params.pk == GNUTLS_PK_ECDSA)) {
+	if (hash_algo == 0 &&
+	    (params.pk == GNUTLS_PK_DSA || params.pk == GNUTLS_PK_ECDSA)) {
 		hash_algo = _gnutls_hash_size_to_sha_hash(hash_data->size);
 	}
 
-	if (params.pk == GNUTLS_PK_RSA && (flags & GNUTLS_PRIVKEY_SIGN_FLAG_TLS1_RSA)) {
+	if (params.pk == GNUTLS_PK_RSA &&
+	    (flags & GNUTLS_PRIVKEY_SIGN_FLAG_TLS1_RSA)) {
 		/* the corresponding signature algorithm is SIGN_RSA_RAW,
 		 * irrespective of hash algorithm. */
 		se = _gnutls_sign_to_entry(GNUTLS_SIGN_RSA_RAW);
@@ -1407,9 +1431,8 @@ gnutls_privkey_sign_hash(gnutls_privkey_t signer,
 
 	FIX_SIGN_PARAMS(params, flags, hash_algo);
 
-	ret = privkey_sign_prehashed(signer, se,
-				     hash_data, signature, &params);
- cleanup:
+	ret = privkey_sign_prehashed(signer, se, hash_data, signature, &params);
+cleanup:
 	if (ret < 0) {
 		_gnutls_switch_fips_state(GNUTLS_FIPS140_OP_ERROR);
 	} else {
@@ -1418,12 +1441,11 @@ gnutls_privkey_sign_hash(gnutls_privkey_t signer,
 	return ret;
 }
 
-static int
-privkey_sign_prehashed(gnutls_privkey_t signer,
-		       const gnutls_sign_entry_st *se,
-		       const gnutls_datum_t * hash_data,
-		       gnutls_datum_t * signature,
-		       gnutls_x509_spki_st * params)
+static int privkey_sign_prehashed(gnutls_privkey_t signer,
+				  const gnutls_sign_entry_st *se,
+				  const gnutls_datum_t *hash_data,
+				  gnutls_datum_t *signature,
+				  gnutls_x509_spki_st *params)
 {
 	int ret;
 	gnutls_datum_t digest;
@@ -1432,9 +1454,7 @@ privkey_sign_prehashed(gnutls_privkey_t signer,
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
 	if (se->id == GNUTLS_SIGN_RSA_RAW) {
-		return privkey_sign_raw_data(signer,
-					     se,
-					     hash_data, signature,
+		return privkey_sign_raw_data(signer, se, hash_data, signature,
 					     params);
 	}
 
@@ -1456,10 +1476,7 @@ privkey_sign_prehashed(gnutls_privkey_t signer,
 		goto cleanup;
 	}
 
-	ret = privkey_sign_raw_data(signer,
-				    se,
-				    &digest, signature,
-				    params);
+	ret = privkey_sign_raw_data(signer, se, &digest, signature, params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1467,7 +1484,7 @@ privkey_sign_prehashed(gnutls_privkey_t signer,
 
 	ret = 0;
 
- cleanup:
+cleanup:
 	_gnutls_free_datum(&digest);
 	return ret;
 }
@@ -1494,12 +1511,9 @@ privkey_sign_prehashed(gnutls_privkey_t signer,
  *
  * Since: 3.1.10
  -*/
-int
-privkey_sign_raw_data(gnutls_privkey_t key,
-		      const gnutls_sign_entry_st *se,
-		      const gnutls_datum_t * data,
-		      gnutls_datum_t * signature,
-		      gnutls_x509_spki_st * params)
+int privkey_sign_raw_data(gnutls_privkey_t key, const gnutls_sign_entry_st *se,
+			  const gnutls_datum_t *data, gnutls_datum_t *signature,
+			  gnutls_x509_spki_st *params)
 {
 	if (unlikely(se == NULL))
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
@@ -1507,27 +1521,26 @@ privkey_sign_raw_data(gnutls_privkey_t key,
 	switch (key->type) {
 #ifdef ENABLE_PKCS11
 	case GNUTLS_PRIVKEY_PKCS11:
-		return _gnutls_pkcs11_privkey_sign(key->key.pkcs11, se,
-						   data, signature,
-						   params);
+		return _gnutls_pkcs11_privkey_sign(key->key.pkcs11, se, data,
+						   signature, params);
 #endif
 	case GNUTLS_PRIVKEY_X509:
 		return _gnutls_pk_sign(se->pk, signature, data,
 				       &key->key.x509->params, params);
 	case GNUTLS_PRIVKEY_EXT:
 		if (unlikely(key->key.ext.sign_data_func == NULL &&
-			key->key.ext.sign_hash_func == NULL &&
-			key->key.ext.sign_func == NULL))
+			     key->key.ext.sign_hash_func == NULL &&
+			     key->key.ext.sign_func == NULL))
 			return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
 		if (_gnutls_pk_is_not_prehashed(se->pk)) {
 			if (!key->key.ext.sign_data_func)
-				return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+				return gnutls_assert_val(
+					GNUTLS_E_INVALID_REQUEST);
 
-			return key->key.ext.sign_data_func(key, se->id,
-							   key->key.ext.userdata,
-							   0,
-							   data, signature);
+			return key->key.ext.sign_data_func(
+				key, se->id, key->key.ext.userdata, 0, data,
+				signature);
 		} else if (key->key.ext.sign_hash_func) {
 			if (se->pk == GNUTLS_PK_RSA) {
 				se = _gnutls_sign_to_entry(GNUTLS_SIGN_RSA_RAW);
@@ -1535,16 +1548,16 @@ privkey_sign_raw_data(gnutls_privkey_t key,
 			}
 
 			/* se may not be set here if we are doing legacy RSA */
-			return key->key.ext.sign_hash_func(key, se->id,
-							   key->key.ext.userdata,
-							   0,
-							   data, signature);
+			return key->key.ext.sign_hash_func(
+				key, se->id, key->key.ext.userdata, 0, data,
+				signature);
 		} else {
 			if (!PK_IS_OK_FOR_EXT2(se->pk))
-				return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+				return gnutls_assert_val(
+					GNUTLS_E_INVALID_REQUEST);
 
-			return key->key.ext.sign_func(key, key->key.ext.userdata,
-						      data, signature);
+			return key->key.ext.sign_func(
+				key, key->key.ext.userdata, data, signature);
 		}
 	default:
 		gnutls_assert();
@@ -1567,11 +1580,9 @@ privkey_sign_raw_data(gnutls_privkey_t key,
  *
  * Since: 2.12.0
  **/
-int
-gnutls_privkey_decrypt_data(gnutls_privkey_t key,
-			    unsigned int flags,
-			    const gnutls_datum_t * ciphertext,
-			    gnutls_datum_t * plaintext)
+int gnutls_privkey_decrypt_data(gnutls_privkey_t key, unsigned int flags,
+				const gnutls_datum_t *ciphertext,
+				gnutls_datum_t *plaintext)
 {
 	switch (key->type) {
 	case GNUTLS_PRIVKEY_X509:
@@ -1579,17 +1590,14 @@ gnutls_privkey_decrypt_data(gnutls_privkey_t key,
 					  ciphertext, &key->key.x509->params);
 #ifdef ENABLE_PKCS11
 	case GNUTLS_PRIVKEY_PKCS11:
-		return _gnutls_pkcs11_privkey_decrypt_data(key->key.pkcs11,
-							   flags,
-							   ciphertext,
-							   plaintext);
+		return _gnutls_pkcs11_privkey_decrypt_data(
+			key->key.pkcs11, flags, ciphertext, plaintext);
 #endif
 	case GNUTLS_PRIVKEY_EXT:
 		if (key->key.ext.decrypt_func == NULL)
 			return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
-		return key->key.ext.decrypt_func(key,
-						 key->key.ext.userdata,
+		return key->key.ext.decrypt_func(key, key->key.ext.userdata,
 						 ciphertext, plaintext);
 	default:
 		gnutls_assert();
@@ -1615,12 +1623,10 @@ gnutls_privkey_decrypt_data(gnutls_privkey_t key,
  * Since: 3.6.5
  **/
 
-int
-gnutls_privkey_decrypt_data2(gnutls_privkey_t key,
-			     unsigned int flags,
-			     const gnutls_datum_t * ciphertext,
-			     unsigned char * plaintext,
-			     size_t plaintext_size)
+int gnutls_privkey_decrypt_data2(gnutls_privkey_t key, unsigned int flags,
+				 const gnutls_datum_t *ciphertext,
+				 unsigned char *plaintext,
+				 size_t plaintext_size)
 {
 	/* Note: except for the backwards compatibility function, no
 	 * conditional code should be called after the decryption
@@ -1633,10 +1639,8 @@ gnutls_privkey_decrypt_data2(gnutls_privkey_t key,
 	    key->key.ext.decrypt_func != NULL) {
 		gnutls_datum_t plain;
 		int ret;
-		ret = key->key.ext.decrypt_func(key,
-						key->key.ext.userdata,
-						ciphertext,
-						&plain);
+		ret = key->key.ext.decrypt_func(key, key->key.ext.userdata,
+						ciphertext, &plain);
 		if (plain.size != plaintext_size) {
 			ret = gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 		} else {
@@ -1654,8 +1658,7 @@ gnutls_privkey_decrypt_data2(gnutls_privkey_t key,
 #ifdef ENABLE_PKCS11
 	case GNUTLS_PRIVKEY_PKCS11:
 		return _gnutls_pkcs11_privkey_decrypt_data2(key->key.pkcs11,
-							    flags,
-							    ciphertext,
+							    flags, ciphertext,
 							    plaintext,
 							    plaintext_size);
 #endif
@@ -1663,8 +1666,7 @@ gnutls_privkey_decrypt_data2(gnutls_privkey_t key,
 		if (key->key.ext.decrypt_func2 == NULL)
 			return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
-		return key->key.ext.decrypt_func2(key,
-						  key->key.ext.userdata,
+		return key->key.ext.decrypt_func2(key, key->key.ext.userdata,
 						  ciphertext, plaintext,
 						  plaintext_size);
 	default:
@@ -1693,7 +1695,7 @@ gnutls_privkey_decrypt_data2(gnutls_privkey_t key,
  * Since: 3.1.0
  **/
 int gnutls_privkey_import_x509_raw(gnutls_privkey_t pkey,
-				   const gnutls_datum_t * data,
+				   const gnutls_datum_t *data,
 				   gnutls_x509_crt_fmt_t format,
 				   const char *password, unsigned int flags)
 {
@@ -1726,9 +1728,8 @@ int gnutls_privkey_import_x509_raw(gnutls_privkey_t pkey,
 		goto cleanup;
 	}
 
-	ret =
-	    gnutls_privkey_import_x509(pkey, xpriv,
-				       GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
+	ret = gnutls_privkey_import_x509(pkey, xpriv,
+					 GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1736,7 +1737,7 @@ int gnutls_privkey_import_x509_raw(gnutls_privkey_t pkey,
 
 	return 0;
 
- cleanup:
+cleanup:
 	gnutls_x509_privkey_deinit(xpriv);
 
 	return ret;
@@ -1757,17 +1758,18 @@ int gnutls_privkey_import_x509_raw(gnutls_privkey_t pkey,
  *
  * Since: 3.1.0
  **/
-int
-gnutls_privkey_import_url(gnutls_privkey_t key, const char *url,
-			  unsigned int flags)
+int gnutls_privkey_import_url(gnutls_privkey_t key, const char *url,
+			      unsigned int flags)
 {
 	unsigned i;
 	int ret;
 
-	for (i=0;i<_gnutls_custom_urls_size;i++) {
-		if (strncmp(url, _gnutls_custom_urls[i].name, _gnutls_custom_urls[i].name_size) == 0) {
+	for (i = 0; i < _gnutls_custom_urls_size; i++) {
+		if (strncmp(url, _gnutls_custom_urls[i].name,
+			    _gnutls_custom_urls[i].name_size) == 0) {
 			if (_gnutls_custom_urls[i].import_key) {
-				ret = _gnutls_custom_urls[i].import_key(key, url, flags);
+				ret = _gnutls_custom_urls[i].import_key(
+					key, url, flags);
 				goto cleanup;
 			}
 			break;
@@ -1798,7 +1800,7 @@ gnutls_privkey_import_url(gnutls_privkey_t key, const char *url,
 	}
 
 	ret = gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
- cleanup:
+cleanup:
 	return ret;
 }
 
@@ -1837,8 +1839,7 @@ void gnutls_privkey_set_pin_function(gnutls_privkey_t key,
  * Since: 3.5.0
  *
  **/
-void gnutls_privkey_set_flags(gnutls_privkey_t key,
-			      unsigned int flags)
+void gnutls_privkey_set_flags(gnutls_privkey_t key, unsigned int flags)
 {
 	key->flags |= flags;
 	if (key->type == GNUTLS_PRIVKEY_X509)
@@ -1920,8 +1921,8 @@ int gnutls_privkey_verify_params(gnutls_privkey_t key)
  *
  * Since: 3.6.0
  **/
-int
-gnutls_privkey_get_spki(gnutls_privkey_t privkey, gnutls_x509_spki_t spki, unsigned int flags)
+int gnutls_privkey_get_spki(gnutls_privkey_t privkey, gnutls_x509_spki_t spki,
+			    unsigned int flags)
 {
 	gnutls_x509_spki_t p = &privkey->key.x509->params.spki;
 
@@ -1933,9 +1934,7 @@ gnutls_privkey_get_spki(gnutls_privkey_t privkey, gnutls_x509_spki_t spki, unsig
 	if (p->pk == GNUTLS_PK_UNKNOWN)
 		return gnutls_assert_val(GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE);
 
-	memcpy(spki, p, sizeof(gnutls_x509_spki_st));
-
-	return 0;
+	return _gnutls_x509_spki_copy(spki, p);
 }
 
 /**
@@ -1952,8 +1951,8 @@ gnutls_privkey_get_spki(gnutls_privkey_t privkey, gnutls_x509_spki_t spki, unsig
  *
  * Since: 3.6.0
  **/
-int
-gnutls_privkey_set_spki(gnutls_privkey_t privkey, const gnutls_x509_spki_t spki, unsigned int flags)
+int gnutls_privkey_set_spki(gnutls_privkey_t privkey,
+			    const gnutls_x509_spki_t spki, unsigned int flags)
 {
 	if (privkey == NULL || privkey->type != GNUTLS_PRIVKEY_X509) {
 		gnutls_assert();
@@ -1972,6 +1971,9 @@ unsigned _gnutls_privkey_compatible_with_sig(gnutls_privkey_t privkey,
 {
 	const gnutls_sign_entry_st *se;
 
+	if (unlikely(privkey == NULL))
+		return gnutls_assert_val(0);
+
 	se = _gnutls_sign_to_entry(sign);
 	if (unlikely(se == NULL))
 		return gnutls_assert_val(0);
@@ -1981,10 +1983,14 @@ unsigned _gnutls_privkey_compatible_with_sig(gnutls_privkey_t privkey,
 	 * negotiating RSA-PSS sig.
 	 */
 
-	if (se->pk != privkey->pk_algorithm) { /* if the PK algorithm of the signature differs to the one on the pubkey */
-		if (!sign_supports_priv_pk_algorithm(se, privkey->pk_algorithm)) {
-			_gnutls_handshake_log("cannot use privkey of %s with %s\n",
-					      gnutls_pk_get_name(privkey->pk_algorithm), se->name);
+	if (se->pk !=
+	    privkey->pk_algorithm) { /* if the PK algorithm of the signature differs to the one on the pubkey */
+		if (!sign_supports_priv_pk_algorithm(se,
+						     privkey->pk_algorithm)) {
+			_gnutls_handshake_log(
+				"cannot use privkey of %s with %s\n",
+				gnutls_pk_get_name(privkey->pk_algorithm),
+				se->name);
 			return 0;
 		}
 	}
@@ -1993,15 +1999,18 @@ unsigned _gnutls_privkey_compatible_with_sig(gnutls_privkey_t privkey,
 		if (privkey->key.ext.info_func) {
 			int ret;
 
-			ret = privkey->key.ext.info_func(privkey,
-						     GNUTLS_SIGN_ALGO_TO_FLAGS(sign)|GNUTLS_PRIVKEY_INFO_HAVE_SIGN_ALGO,
-						     privkey->key.ext.userdata);
+			ret = privkey->key.ext.info_func(
+				privkey,
+				GNUTLS_SIGN_ALGO_TO_FLAGS(sign) |
+					GNUTLS_PRIVKEY_INFO_HAVE_SIGN_ALGO,
+				privkey->key.ext.userdata);
 			if (ret != -1)
 				return ret;
 
 			/* use the old flag */
-			ret = privkey->key.ext.info_func(privkey, GNUTLS_PRIVKEY_INFO_SIGN_ALGO,
-						     privkey->key.ext.userdata);
+			ret = privkey->key.ext.info_func(
+				privkey, GNUTLS_PRIVKEY_INFO_SIGN_ALGO,
+				privkey->key.ext.userdata);
 			if (ret == (int)sign)
 				return 1;
 		}
@@ -2012,7 +2021,8 @@ unsigned _gnutls_privkey_compatible_with_sig(gnutls_privkey_t privkey,
 	}
 #ifdef ENABLE_PKCS11
 	else if (privkey->type == GNUTLS_PRIVKEY_PKCS11) {
-		if (privkey->pk_algorithm == GNUTLS_PK_RSA && se->pk == GNUTLS_PK_RSA_PSS) {
+		if (privkey->pk_algorithm == GNUTLS_PK_RSA &&
+		    se->pk == GNUTLS_PK_RSA_PSS) {
 			if (!privkey->key.pkcs11->rsa_pss_ok)
 				return 0;
 		}
@@ -2021,3 +2031,40 @@ unsigned _gnutls_privkey_compatible_with_sig(gnutls_privkey_t privkey,
 
 	return 1;
 }
+
+/**
+ * gnutls_privkey_derive_secret:
+ * @privkey: a private key of type #gnutls_privkey_t
+ * @pubkey: a public key of type #gnutls_pubkey_t
+ * @nonce: an optional nonce value
+ * @secret: where shared secret will be stored
+ * @flags: must be zero
+ *
+ * This function will calculate a shared secret from our @privkey and
+ * peer's @pubkey. The result will be stored in @secret, whose data
+ * member should be freed after use using gnutls_free(). @privkey and
+ * @pubkey must be backed by the X.509 keys.
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, otherwise a
+ *   negative error value.
+ *
+ * Since: 3.8.2
+ **/
+int gnutls_privkey_derive_secret(gnutls_privkey_t privkey,
+				 gnutls_pubkey_t pubkey,
+				 const gnutls_datum_t *nonce,
+				 gnutls_datum_t *secret, unsigned int flags)
+{
+	if (unlikely(privkey == NULL || privkey->type != GNUTLS_PRIVKEY_X509)) {
+		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+	}
+
+	if (unlikely(pubkey == NULL ||
+		     pubkey->params.algo != privkey->pk_algorithm)) {
+		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+	}
+
+	return _gnutls_pk_derive_nonce(privkey->pk_algorithm, secret,
+				       &privkey->key.x509->params,
+				       &pubkey->params, nonce);
+}
