@@ -25,10 +25,10 @@
  */
 
 #include "gnutls_int.h"
-#include <common.h>
-#include <x509.h>
-#include <x509_int.h>
-#include <num.h>
+#include "common.h"
+#include "x509.h"
+#include "x509_int.h"
+#include "num.h"
 #include "errors.h"
 #include "hello_ext.h"
 #include "ip.h"
@@ -1486,7 +1486,8 @@ static void print_pubkey(gnutls_buffer_st *str, const char *key_name,
 
 	switch (pk) {
 	case GNUTLS_PK_RSA:
-	case GNUTLS_PK_RSA_PSS: {
+	case GNUTLS_PK_RSA_PSS:
+	case GNUTLS_PK_RSA_OAEP: {
 		gnutls_datum_t m, e;
 
 		err = gnutls_pubkey_get_pk_rsa_raw(pubkey, &m, &e);
