@@ -121,20 +121,21 @@ static const struct option long_options[] =
   { "ecdsa", no_argument, 0, CHAR_MAX + 65 },
   { "hash", required_argument, 0, CHAR_MAX + 66 },
   { "salt-size", required_argument, 0, CHAR_MAX + 67 },
-  { "inder", no_argument, 0, CHAR_MAX + 68 },
-  { "inraw", no_argument, 0, CHAR_MAX + 70 },
-  { "no-inder", no_argument, 0, CHAR_MAX + 69 },
-  { "outder", no_argument, 0, CHAR_MAX + 71 },
-  { "outraw", no_argument, 0, CHAR_MAX + 73 },
-  { "no-outder", no_argument, 0, CHAR_MAX + 72 },
-  { "disable-quick-random", no_argument, 0, CHAR_MAX + 74 },
-  { "template", required_argument, 0, CHAR_MAX + 75 },
-  { "stdout-info", no_argument, 0, CHAR_MAX + 76 },
-  { "ask-pass", no_argument, 0, CHAR_MAX + 77 },
-  { "pkcs-cipher", required_argument, 0, CHAR_MAX + 78 },
-  { "provider", required_argument, 0, CHAR_MAX + 79 },
-  { "text", no_argument, 0, CHAR_MAX + 80 },
-  { "no-text", no_argument, 0, CHAR_MAX + 81 },
+  { "label", required_argument, 0, CHAR_MAX + 68 },
+  { "inder", no_argument, 0, CHAR_MAX + 69 },
+  { "inraw", no_argument, 0, CHAR_MAX + 71 },
+  { "no-inder", no_argument, 0, CHAR_MAX + 70 },
+  { "outder", no_argument, 0, CHAR_MAX + 72 },
+  { "outraw", no_argument, 0, CHAR_MAX + 74 },
+  { "no-outder", no_argument, 0, CHAR_MAX + 73 },
+  { "disable-quick-random", no_argument, 0, CHAR_MAX + 75 },
+  { "template", required_argument, 0, CHAR_MAX + 76 },
+  { "stdout-info", no_argument, 0, CHAR_MAX + 77 },
+  { "ask-pass", no_argument, 0, CHAR_MAX + 78 },
+  { "pkcs-cipher", required_argument, 0, CHAR_MAX + 79 },
+  { "provider", required_argument, 0, CHAR_MAX + 80 },
+  { "text", no_argument, 0, CHAR_MAX + 81 },
+  { "no-text", no_argument, 0, CHAR_MAX + 82 },
   { "version", optional_argument, 0, 'v' },
   { "help", no_argument, 0, 'h' },
   { "more-help", no_argument, 0, '!' },
@@ -498,56 +499,61 @@ process_options (int argc, char **argv)
         opts->value.salt_size = parse_number(optarg);
         opts->enabled.salt_size = true;
         break;
-      case CHAR_MAX + 68: /* --inder */
-      case CHAR_MAX + 70: /* --inraw */
+      case CHAR_MAX + 68: /* --label */
+        opts->present.label = true;
+        opts->arg.label = optarg;
+        opts->enabled.label = true;
+        break;
+      case CHAR_MAX + 69: /* --inder */
+      case CHAR_MAX + 71: /* --inraw */
         opts->present.inder = true;
         opts->enabled.inder = true;
         break;
-      case CHAR_MAX + 69: /* --no-inder */
+      case CHAR_MAX + 70: /* --no-inder */
         opts->present.inder = true;
         opts->enabled.inder = false;
         break;
-      case CHAR_MAX + 71: /* --outder */
-      case CHAR_MAX + 73: /* --outraw */
+      case CHAR_MAX + 72: /* --outder */
+      case CHAR_MAX + 74: /* --outraw */
         opts->present.outder = true;
         opts->enabled.outder = true;
         break;
-      case CHAR_MAX + 72: /* --no-outder */
+      case CHAR_MAX + 73: /* --no-outder */
         opts->present.outder = true;
         opts->enabled.outder = false;
         break;
-      case CHAR_MAX + 74: /* --disable-quick-random */
+      case CHAR_MAX + 75: /* --disable-quick-random */
         opts->present.disable_quick_random = true;
         opts->enabled.disable_quick_random = true;
         break;
-      case CHAR_MAX + 75: /* --template */
+      case CHAR_MAX + 76: /* --template */
         opts->present.template = true;
         opts->arg.template = optarg;
         opts->enabled.template = true;
         break;
-      case CHAR_MAX + 76: /* --stdout-info */
+      case CHAR_MAX + 77: /* --stdout-info */
         opts->present.stdout_info = true;
         opts->enabled.stdout_info = true;
         break;
-      case CHAR_MAX + 77: /* --ask-pass */
+      case CHAR_MAX + 78: /* --ask-pass */
         opts->present.ask_pass = true;
         opts->enabled.ask_pass = true;
         break;
-      case CHAR_MAX + 78: /* --pkcs-cipher */
+      case CHAR_MAX + 79: /* --pkcs-cipher */
         opts->present.pkcs_cipher = true;
         opts->arg.pkcs_cipher = optarg;
         opts->enabled.pkcs_cipher = true;
         break;
-      case CHAR_MAX + 79: /* --provider */
+      case CHAR_MAX + 80: /* --provider */
         opts->present.provider = true;
         opts->arg.provider = optarg;
         opts->enabled.provider = true;
         break;
-      case CHAR_MAX + 80: /* --text */
+      case CHAR_MAX + 81: /* --text */
         opts->present.text = true;
         opts->enabled.text = true;
         break;
-      case CHAR_MAX + 81: /* --no-text */
+      case CHAR_MAX + 82: /* --no-text */
         opts->present.text = true;
         opts->enabled.text = false;
         break;
@@ -659,7 +665,7 @@ process_options (int argc, char **argv)
       if (!OPT_ARG_VERSION || !strcmp (OPT_ARG_VERSION, "c"))
         {
           const char str[] =
-            "certtool 3.8.3\n"
+            "certtool 3.8.5\n"
             "Copyright (C) 2000-2023 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -672,14 +678,14 @@ process_options (int argc, char **argv)
       else if (!strcmp (OPT_ARG_VERSION, "v"))
         {
           const char str[] =
-            "certtool 3.8.3\n";
+            "certtool 3.8.5\n";
           fprintf (stdout, "%s", str);
           exit(0);
         }
       else if (!strcmp (OPT_ARG_VERSION, "n"))
         {
           const char str[] =
-            "certtool 3.8.3\n"
+            "certtool 3.8.5\n"
             "Copyright (C) 2000-2023 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -826,6 +832,7 @@ usage (FILE *out, int status)
     "       --cprint               In certain operations it prints the information in C-friendly format\n"
     "       --hash=str             Hash algorithm to use for signing\n"
     "       --salt-size=num        Specify the RSA-PSS key default salt size\n"
+    "       --label=str            Specify the RSA-OAEP label, encoded in hexadecimal\n"
     "       --inder                Use DER format for input certificates, private keys, and DH parameters \n"
     "       --inraw                an alias for the 'inder' option\n"
     "       --outder               Use DER format for output certificates, private keys, and DH parameters\n"
