@@ -14,12 +14,11 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GnuTLS; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * along with GnuTLS.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -28,36 +27,35 @@
 
 #if defined(_WIN32)
 
-int main()
+int main(void)
 {
 	exit(77);
 }
 
 #else
 
-# include <sys/types.h>
-# include <netinet/in.h>
-# include <sys/socket.h>
-# include <sys/wait.h>
-# include <arpa/inet.h>
-# include <unistd.h>
-# include <gnutls/gnutls.h>
-# include <gnutls/dtls.h>
-# include <signal.h>
+#include <sys/types.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <sys/wait.h>
+#include <arpa/inet.h>
+#include <unistd.h>
+#include <gnutls/gnutls.h>
+#include <gnutls/dtls.h>
+#include <signal.h>
 
-# ifndef MSG_NOSIGNAL
+#ifndef MSG_NOSIGNAL
 
 int main(void)
 {
 	exit(77);
 }
 
-# else
+#else
 
-# include "utils.h"
+#include "utils.h"
 
-static
-void sigpipe(int sig)
+static void sigpipe(int sig)
 {
 	_exit(2);
 }
@@ -84,12 +82,13 @@ static void client(int fd)
 	/* Initialize TLS session
 	 */
 	gnutls_init(&session, GNUTLS_CLIENT);
-	gnutls_handshake_set_timeout(session, 20 * 1000);
+	gnutls_handshake_set_timeout(session, get_timeout());
 
 	/* Use default priorities */
-	gnutls_priority_set_direct(session,
-				   "NONE:+VERS-TLS1.0:+CIPHER-ALL:+MAC-ALL:+SIGN-ALL:+COMP-ALL:+ANON-ECDH:+CURVE-ALL",
-				   NULL);
+	gnutls_priority_set_direct(
+		session,
+		"NONE:+VERS-TLS1.0:+CIPHER-ALL:+MAC-ALL:+SIGN-ALL:+COMP-ALL:+ANON-ECDH:+CURVE-ALL",
+		NULL);
 
 	/* put the anonymous credentials to the current session
 	 */
@@ -101,8 +100,8 @@ static void client(int fd)
 	 */
 	do {
 		ret = gnutls_handshake(session);
-	}
-	while (ret < 0 && (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED));
+	} while (ret < 0 &&
+		 (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED));
 
 	ret = gnutls_record_recv(session, buf, sizeof(buf));
 	if (ret < 0 || ret != sizeof(buf)) {
@@ -124,14 +123,14 @@ static void client(int fd)
 	gnutls_global_deinit();
 
 	if (ret < 0) {
-		fail("client: Handshake failed with unexpected reason: %s\n", gnutls_strerror(ret));
+		fail("client: Handshake failed with unexpected reason: %s\n",
+		     gnutls_strerror(ret));
 	} else {
 		if (debug)
 			success("client: Handshake was completed\n");
 	}
 }
 
-
 /* These are global */
 pid_t child;
 
@@ -152,14 +151,15 @@ static void server(int fd)
 
 	gnutls_anon_allocate_server_credentials(&anoncred);
 
-	gnutls_init(&session, GNUTLS_SERVER|GNUTLS_NO_SIGNAL);
+	gnutls_init(&session, GNUTLS_SERVER | GNUTLS_NO_SIGNAL);
 
 	/* avoid calling all the priority functions, since the defaults
 	 * are adequate.
 	 */
-	gnutls_priority_set_direct(session,
-				   "NONE:+VERS-TLS1.0:+CIPHER-ALL:+MAC-ALL:+SIGN-ALL:+COMP-ALL:+ANON-ECDH:+CURVE-ALL",
-				   NULL);
+	gnutls_priority_set_direct(
+		session,
+		"NONE:+VERS-TLS1.0:+CIPHER-ALL:+MAC-ALL:+SIGN-ALL:+COMP-ALL:+ANON-ECDH:+CURVE-ALL",
+		NULL);
 
 	gnutls_credentials_set(session, GNUTLS_CRD_ANON, anoncred);
 
@@ -167,8 +167,8 @@ static void server(int fd)
 
 	do {
 		ret = gnutls_handshake(session);
-	}
-	while (ret < 0 && (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED));
+	} while (ret < 0 &&
+		 (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED));
 
 	if (ret < 0) {
 		fail("error in handshake: %s\n", gnutls_strerror(ret));
@@ -176,7 +176,7 @@ static void server(int fd)
 	}
 
 	memset(buf, 0, sizeof(buf));
-	for (i=0;i<5;i++) {
+	for (i = 0; i < 5; i++) {
 		sleep(3);
 		ret = gnutls_record_send(session, buf, sizeof(buf));
 		if (ret < 0)
@@ -188,7 +188,6 @@ static void server(int fd)
 	gnutls_deinit(session);
 	gnutls_anon_free_server_credentials(anoncred);
 	gnutls_global_deinit();
-
 }
 
 static void start(void)
@@ -240,5 +239,5 @@ void doit(void)
 	start();
 }
 
-# endif /* MSG_NOSIGNAL */
-#endif				/* _WIN32 */
+#endif /* MSG_NOSIGNAL */
+#endif /* _WIN32 */
